@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -77,6 +78,14 @@ module SiSU_AO_Numbering
       data=set_heading_top(data) unless @md.set_heading_top
       [data,tags_map,ocn_html_seg_map]
     end
+    def set_tags(tags,tag)
+      tags=if not tag.empty? \
+      and tag !~/^\d+$/
+        tag=tag.gsub(/[^a-z0-9._-]/,'')
+        [tag,tags].flatten
+      else tags
+      end
+    end
     def number_plaintext_para(data)
       @tuned_file=[]
       data.each do |dob|
@@ -97,9 +106,9 @@ module SiSU_AO_Numbering
     def number_sub_heading(dob,num,title_no)
       unless dob.obj =~/\d+\.|(?:chapter|article|section|clause)\s+\d+/i #name selection arbitrary, fix
         dob.obj=case dob.name
-        when /-/;  dob.obj.gsub(/^/,"#{title_no} ")
-        when /^#/; dob.obj.gsub(/^/,"#{title_no} ")
-        when /^[a-z_\.]+/; dob.obj.gsub(/^/,"#{title_no} ")
+        when /-/          then dob.obj.gsub(/^/,"#{title_no} ")
+        when /^#/         then dob.obj.gsub(/^/,"#{title_no} ")
+        when /^[a-z_\.]+/ then dob.obj.gsub(/^/,"#{title_no} ")
         else
           dob.name=title_no if dob.name=~/^$/ #where title contains title number
           dob.obj.gsub(/^/,"#{title_no} ") if title_no =~/\d+/ #main, where title number is to be provided #watch changed placement
@@ -157,7 +166,7 @@ module SiSU_AO_Numbering
             @subnumber=1
             @subnumber=0 if dob.ln==no1
           end
-          if dob.ln.to_s =~/^[1-6]/ \
+          if dob.ln.to_s =~/^[0-6]/ \
           and not dob.toc_ \
           and dob.obj !~/#{Mx[:fa_o]}(?:~#|-#)#{Mx[:fa_c]}/ # <-- fix
             if dob.ln==no1
@@ -167,10 +176,10 @@ module SiSU_AO_Numbering
               and not @md.seg_names.include?(title_no)
                 if dob.ln==no1
                   dob.name="#{title_no}" if not dob.name
-                  dob.tags=[title_no,dob.tags].flatten if title_no !~/^\d+$/  #check whether will work across file types with stop signs
+                  dob.tags=set_tags(dob.tags,title_no)
                   tag=dob.obj.gsub(/(Article|Clause|Section|Chapter)\s+/,"\\1_#{title_no}").downcase
                   tag=heading_tag_clean(tag)
-                  dob.tags=[tag,dob.tags].flatten if tag !~/^\d+$/ #check whether will work across file types with stop signs
+                  dob.tags=set_tags(dob.tags,tag)
                   dob.obj=(dob.obj =~/(Article|Clause|Section)\s+/) \
                   ? (dob.obj.gsub(/(Article|Clause|Section)\s+/,"\\1 #{title_no} "))
                   : (dob.obj.gsub(/^/,"#{title_no}. ")) #fix stop later
@@ -178,7 +187,7 @@ module SiSU_AO_Numbering
                 if dob.ln !=no1 \
                 and dob.obj =~/^[\d.]+\s/ #fix -> if the title starts with a numbering scheme, do not auto-number, review
                   dob.name ="#{title_no}" if not dob.name
-                  dob.tags=[title_no,dob.tags].flatten if title_no !~/^\d+$/ #check whether will work across file types with stop signs
+                  dob.tags=set_tags(dob.tags,title_no)
                   dob.obj=dob.obj.gsub(/^/,"#{title_no}. ")
                 end
                 @md.seg_names << title_no
@@ -186,28 +195,28 @@ module SiSU_AO_Numbering
               if dob.ln!=no1 \
               and dob.name!~/^[a-z_\.]+$/ \
               and dob.obj !~/[A-Z]\.?\s/ #bug -> tmp fix, excludes A. B. C. lettering, but not roman numerals, is arbitrary, review required # not fixed, work on
-                dob.tags=[title_no,dob.tags].flatten if title_no !~/^\d+$/ #check whether will work across file types with stop signs
+                dob.tags=set_tags(dob.tags,title_no)
                 dob.obj=dob.obj.gsub(/^/i,"#{title_no}. ")
               end
             end
             if dob.ln==no1         #watch because here you change dob.name
-              dob.tags=["h#{title_no}",dob.tags].flatten #check whether will work across file types with stop signs
+              dob.tags=set_tags(dob.tags,"h#{title_no}")
             end
             if dob.ln==no2         #watch because here you change dob.name
               t_no2+=1; t_no3=0
               title_no="#{t_no1}.#{t_no2}"
-              dob.tags=["h#{title_no}",dob.tags].flatten #check whether will work across file types with stop signs
+              dob.tags=set_tags(dob.tags,"h#{title_no}")
               dob=number_sub_heading(dob,no2,title_no)
             end
             if dob.ln==no3         #watch because here you change dob.name
               t_no3+=1
               title_no="#{t_no1}.#{t_no2}.#{t_no3}"
-              dob.tags=["h#{title_no}",dob.tags].flatten #check whether will work across file types with stop signs
+              dob.tags=set_tags(dob.tags,"h#{title_no}")
               dob=number_sub_heading(dob,no3,title_no)
             end
-          elsif dob.ln.to_s =~/^[1-6]/ \
+          elsif dob.ln.to_s =~/^[0-6]/ \
           and dob.name =~ /^[\w-]+-/ # endnotes, watch2005# endnotes, watch2005
-            dob.tags=[dob.name,dob.tags].flatten if dob.name !~/^\d+$/  #check whether will work across file types with stop signs
+            dob.tags=set_tags(dob.tags,dob.name)
             dob.name.gsub(/^([a-z_\.]+)-$/,'\1')
           end
         elsif dob.is ==:heading \
@@ -215,16 +224,16 @@ module SiSU_AO_Numbering
         and @md.markup =~/num_extract/ #AS DANGEROUS force enable with document, note already does this type of numbering for cisg, locate and coordinate logic, is currently misplaced in code, chengwei inspired 2004w23/4
           #here lies a bug, as is nil when run from -Dv --update, FIX
           if (dob.name.nil? or dob.name.empty?) \
-          and dob.ln.to_s =~/^[1-9]/ \
+          and dob.ln.to_s =~/^[0-9]/ \
           and dob.obj =~ /^([\d\.]+)/ #risky (must be unique) consider output to 4~~\d instead of 4~\d
             dob.name=$1
-            dob.tags=[dob.name,dob.tags].flatten if dob.name !~/^\d+$/ #check whether will work across file types with stop signs
+            dob.tags=set_tags(dob.tags,dob.name)
           end
           if @md.toc_lev_limit
           end
         elsif defined? dob.name \
         and  dob.name
-          dob.tags=[dob.name,dob.tags].flatten if dob.name !~/^\d+$/ #check whether will work across file types with stop signs
+          dob.tags=set_tags(dob.tags,dob.name)
         end
         dob.tags=dob.tags.uniq if defined? dob.tags
         @tuned_file << dob
@@ -249,7 +258,7 @@ module SiSU_AO_Numbering
         || dob.of ==:para \
         || dob.of ==:block
           if dob.is ==:heading \
-          and dob.ln.to_s=~/^[1-9]/                                                    #% sub-number system, (baby numbering) reset with any change of major number (more obviously should be placed in number titles, but that is conditionally executed, check and move later)
+          and dob.ln.to_s=~/^[0-9]/                                                    #% sub-number system, (baby numbering) reset with any change of major number (more obviously should be placed in number titles, but that is conditionally executed, check and move later)
             number_small,letter_small=0,0
           elsif dob.is ==:para
             if dob.obj =~/^#[ 1]/ \
@@ -311,7 +320,7 @@ module SiSU_AO_Numbering
             if @md.seg_names.is_a?(Array) \
             and not @md.seg_names.include?(possible_seg_name)
               dob.name=possible_seg_name
-              dob.tags=[dob.name,dob.tags].flatten if dob.name !~/^\d+$/
+              dob.tags=set_tags(dob.tags,dob.name)
               @md.seg_names << possible_seg_name
             elsif (@md.opt.act[:verbose_plus][:set]==:on \
             or @md.opt.act[:maintenance][:set]==:on)
@@ -322,7 +331,7 @@ module SiSU_AO_Numbering
           and dob.name                                     #extract segment name from embedded document structure info
             if @md.seg_names.is_a?(Array) \
             and not @md.seg_names.include?(dob.name)
-              dob.tags=[dob.name,dob.tags].flatten if dob.name !~/^\d+$/
+              dob.tags=set_tags(dob.tags,dob.name)
               @md.seg_names << dob.name
             end
           end
@@ -333,7 +342,7 @@ module SiSU_AO_Numbering
             if @md.seg_names.is_a?(Array) \
             and not @md.seg_names.include?(segn_auto)
              dob.name=segn_auto
-             dob.tags=[dob.name,dob.tags].flatten if dob.name !~/^\d+$/ #check whether will work across file types with stop signs
+             dob.tags=set_tags(dob.tags,dob.name)
               @md.seg_names << segn_auto
             else puts 'segment name (numbering) error'
             end
@@ -372,7 +381,7 @@ module SiSU_AO_Numbering
           : @segname
           tags["#{dob.ocn}"]={ segname: @segname }
           ocn_html_seg[dob.ocn]=if (dob.is==:heading || dob.is==:heading_insert)
-            if dob.ln =~/[1-3]/
+            if dob.ln =~/[0-3]/
               { seg: nil, level: dob.ln }
             else #elsif dob.ln =~/[4-6]/
               { seg: @seg, level: dob.ln }
@@ -445,7 +454,7 @@ module SiSU_AO_Numbering
         @tuned_file=[]
         data.each do |dob|
           unless @md.set_heading_seg
-            if defined? dob.ln and dob.ln.to_s !~/^[123]/m \
+            if defined? dob.ln and dob.ln.to_s !~/^[0-3]/m \
             and dob.obj !~/\A\s*\Z/m \
             and dob.is !=:layout
               @md.set_heading_seg=true
