@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -73,12 +74,12 @@ module  SiSU_CGI_PgSQL
       get_init=SiSU_Env::GetInit.new
       @rc=get_init.sisu_yaml.rc
       @name_of={}
-      @name_of[:output_dir_structure]=if @opt.dir_structure_by.to_s =~/(?:language|filetype|filename)/
-        @opt.dir_structure_by.to_s
+      @name_of[:output_dir_structure]=if opt.dir_structure_by.to_s =~/(?:language|filetype|filename)/
+        opt.dir_structure_by.to_s
       else 'language'
       end
-      @name_of[:lingual]=if @opt.lingual.to_s =~/(?:mono|multi)/
-        @opt.lingual.to_s
+      @name_of[:lingual]=if opt.lingual.to_s =~/(?:mono|multi)/
+        opt.lingual.to_s
       else 'multi'
       end
       if defined? @rc['search'] \
@@ -92,13 +93,13 @@ module  SiSU_CGI_PgSQL
         @name_of[:db]=@env.path.stub_pwd #'sisu' #breaks if not present
         false
       end
-      @name_of[:host_url_cgi]="#{@env.url.webserv_base_cgi(@opt)}/cgi-bin"
-      @name_of[:host_url_docs]=@env.url.webserv_files_from_db(@opt)
-      @name_of[:cgi_script]=@env.url.cgi_sample_search_form_name(@opt)
-      @name_of[:user]=@db.psql.user(@opt)
+      @name_of[:host_url_cgi]="#{@env.url.webserv_base_cgi(opt)}/cgi-bin"
+      @name_of[:host_url_docs]=@env.url.webserv_files_from_db(opt)
+      @name_of[:cgi_script]=@env.url.cgi_sample_search_form_name(opt)
+      @name_of[:user]=@db.psql.user(opt)
       @cgi_file_name=@name_of[:cgi_script]
-      @image_src="#{@env.url.webserv_base_cgi(@opt)}/_sisu/image_sys"
-      @common=SiSU_CGI_SQL::CGI_Common.new(@webserv,@opt,@image_src,@env)
+      @image_src="#{@env.url.webserv_base_cgi(opt)}/_sisu/image_sys"
+      @common=SiSU_CGI_SQL::CGI_Common.new(@webserv,opt,@image_src,@env)
     end
     def pgsql
       serve=[]
@@ -166,20 +167,20 @@ module  SiSU_CGI_PgSQL
             # set file permissions to 755
         WOK
         a=case @webserv
-        when /pwd/; ''
+        when /pwd/ then ''
         else <<-WOK
 
               sudo cp -vi #{Dir.pwd}/#{@cgi_file_name} /usr/lib/cgi-bin/.; \\
               sudo chmod -v 755  /usr/lib/cgi-bin/#{@cgi_file_name}
           WOK
         end
-        SiSU_Screen::Ansi.new(opt.act[:color_state][:set],a).warn
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],a).warn
         a=<<-WOK
               #{@env.webserv_base_cgi(@opt)}/cgi-bin/#{@cgi_file_name}
         WOK
-        SiSU_Screen::Ansi.new(opt.act[:color_state][:set],a).print_blue
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],a).print_blue
         a="\n\t(to create and populate postgresql database see 'man sisu' and in particular the --pg option)\n\t[the database to be used for this directory (#{@db.psql.db}) will have to be created manually if it does not exist,\n\tusing postgresql tools directly: 'createdb #{@db.psql.db}' for a list of existing databases try 'psql --list']"
-        SiSU_Screen::Ansi.new(opt.act[:color_state][:set],a).txt_grey
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],a).txt_grey
       else puts 'failed in attempt to write #{@cgi_file_name} to present directory,  is directory writable?'
       end
     end
@@ -191,9 +192,13 @@ module  SiSU_CGI_PgSQL
  * Description: generates naive cgi search form for search of sisu database (pgsql)
 #{gpl}
 =end
-      require 'cgi'
-      require 'fcgi'
-      require 'dbi'
+      begin
+        require 'cgi'
+        require 'fcgi'
+        require 'dbi'
+      rescue LoadError
+        puts 'cgi, fcgi or dbi NOT FOUND (LoadError)'
+      end
       @stub_default='#{@name_of[:db]}'
       @image_src='#{@image_src}'
       @hosturl_cgi='#{@name_of[:host_url_cgi]}'
