@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -68,18 +69,18 @@ module  SiSU_CGI_SQLite
       @opt,@webserv=opt,webserv
       @cX=SiSU_Screen::Ansi.new(opt.act[:color_state][:set]).cX
       @env=SiSU_Env::InfoEnv.new('',opt)
-      @image_src="#{@env.url.webserv_cgi(@opt)}/_sisu/image_sys"
+      @image_src="#{@env.url.webserv_cgi(opt)}/_sisu/image_sys"
       @name_of={}
-      @name_of[:output_dir_structure]=if @opt.dir_structure_by.to_s =~/(?:language|filetype|filename)/
-        @opt.dir_structure_by.to_s
+      @name_of[:output_dir_structure]=if opt.dir_structure_by.to_s =~/(?:language|filetype|filename)/
+        opt.dir_structure_by.to_s
       else 'language'
       end
-      @name_of[:lingual]=if @opt.lingual.to_s =~/(?:mono|multi)/
-        @opt.lingual.to_s
+      @name_of[:lingual]=if opt.lingual.to_s =~/(?:mono|multi)/
+        opt.lingual.to_s
       else 'multi'
       end
-      @common=SiSU_CGI_SQL::CGI_Common.new(@webserv,@opt,@image_src,@env)
-      @cgi_file_name=@env.url.cgi_sample_search_form_name(@opt)
+      @common=SiSU_CGI_SQL::CGI_Common.new(@webserv,opt,@image_src,@env)
+      @cgi_file_name=@env.url.cgi_sample_search_form_name(opt)
       @name_of_sqlite_db_file='sisu_sqlite.db'
     end
     def sqlite
@@ -99,13 +100,13 @@ module  SiSU_CGI_SQLite
       end
       f2 <<  %{          selected_db=case cgi['db']\n}
       serve.each do |x|
-        f2 << %{           when /#{Db[:name_prefix]}#{x}/; '<option value="#{Db[:name_prefix]}#{x}">#{x}</option>'\n}
+        f2 << %{           when /#{Db[:name_prefix]}#{x}/ then '<option value="#{Db[:name_prefix]}#{x}">#{x}</option>'\n}
       end
       f2 << "          end\n"
       f3 << %{          db_name='#{@name_of_sqlite_db_file}'\n}
       f3 << %{          db_sqlite=case cgi['db']\n}
       serve.each do |x|
-        f3 << %{          when /#{Db[:name_prefix]}#{x}/;                      "#{@env.path.webserv}/#{x}/\#{db_name}"\n}
+        f3 << %{          when /#{Db[:name_prefix]}#{x}/ then "#{@env.path.webserv}/#{x}/\#{db_name}"\n}
       end
       f3 << %{           else  '#{@env.path.webserv}/#{serve[0]}/\#{db_name}'\n          end\n}
       if FileTest.writable?('.')
@@ -138,7 +139,7 @@ module  SiSU_CGI_SQLite
             # set file permissions to 755
         WOK
         a=case @webserv
-        when /pwd/; ''
+        when /pwd/ then ''
         else <<-WOK
 
               sudo cp -vi #{Dir.pwd}/#{@cgi_file_name} /usr/lib/cgi-bin/.; \\
@@ -146,13 +147,13 @@ module  SiSU_CGI_SQLite
           WOK
         end
         b='(to create and populate sisu sqlite database see "man sisu" and in particular the -d flag)'
-        SiSU_Screen::Ansi.new(opt.act[:color_state][:set],a,b).warn
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],a,b).warn
         a=<<-WOK
 
               #{@env.webserv_base_cgi(@opt)}/cgi-bin/#{@cgi_file_name}
 
         WOK
-        SiSU_Screen::Ansi.new(opt.act[:color_state][:set],a).print_blue
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],a).print_blue
       else puts "failed in attempt to write #{@cgi_file_name} to present directory, is directory writable?"
       end
     end
@@ -164,9 +165,13 @@ module  SiSU_CGI_SQLite
  * Description: generates naive cgi search form for search of sisu database (sqlite)
 #{gpl}
 =end
-      require 'cgi'
-      require 'fcgi'
-      require 'dbi'
+      begin
+        require 'cgi'
+        require 'fcgi'
+        require 'dbi'
+      rescue LoadError
+        puts 'cgi, fcgi or dbi NOT FOUND (LoadError)'
+      end
       @stub_default='sisu_sqlite'
       @image_src='#{@image_src}'
       @hosturl_cgi='#{@env.url.webserv_base_cgi(@opt)}/cgi-bin'
