@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -239,12 +240,13 @@ WOK
         end
       end
     protected
-      def location_scroll(wordlocation,show)
-        %{<a href="doc#{@md.lang_code_insert}#{Sfx[:html]}\##{wordlocation}">#{wordlocation}</a>;  }
+      def location_scroll(wordlocation,show)                    # not used
+        %{<a href="doc#{@md.lang_code_insert}#{Sfx[:html]}\##{Mx[:ocn_id_char]}#{wordlocation}">#{wordlocation}</a>;  }
       end
-      def location_seg(wordlocation,show) ##fix
+      def location_seg(wordlocation,show)
         unless wordlocation.nil?
-          wl=wordlocation.gsub(/(.+?)\#(\d+)/,"\\1#{@md.lang_code_insert}#{Sfx[:html]}#\\2")
+          wl=wordlocation.gsub(/(.+?)\#(\d+)/,
+            "\\1#{@md.lang_code_insert}#{Sfx[:html]}##{Mx[:ocn_id_char]}\\2")     # id="o\d+" always available; a name="\d+" not available if html strict used
           case wordlocation
           when /#{@rxp_t1}|@rxp_t2}|#{@rxp_t3}/
             %{[<a href="doc#{@md.lang_code_insert}#{Sfx[:html]}##{show}">H</a>]#{show},  }
@@ -326,9 +328,9 @@ WOK
                       end
                     else
                       @word_map[word] << case line
-                      when @rxp_lv1; location_seg('T1',ocn) #fix @rxp_lv #  Mx[:lv_o]
-                      when @rxp_lv2; location_seg('T2',ocn) #fix @rxp_lv #  Mx[:lv_o]
-                      when @rxp_lv3; location_seg('T3',ocn) #fix @rxp_lv #  Mx[:lv_o]
+                      when @rxp_lv1 then location_seg('T1',ocn) #fix @rxp_lv #  Mx[:lv_o]
+                      when @rxp_lv2 then location_seg('T2',ocn) #fix @rxp_lv #  Mx[:lv_o]
+                      when @rxp_lv3 then location_seg('T3',ocn) #fix @rxp_lv #  Mx[:lv_o]
                       end
                     end
                   end
