@@ -9,7 +9,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -61,11 +62,11 @@
 
 =end
 #Ax,Xx,Mx,Rx,Hx,Dx,Px,Ep,Db,Gt,Tex=Array.new(11){{}}
-YEAR='2013'
+YEAR='2014'
 Sfx={
   txt:                       '.txt',
   txt_textile:               '.textile',
-  txt_asciidoc:              '.asciidoc.txt',
+  txt_asciidoc:              '.ad',
   txt_markdown:              '.md',
   txt_rst:                   '.rst',
   html:                      '.html',
@@ -100,7 +101,15 @@ Xx={
   html_relative1:            '※',
 }
 Mx={
+  ocn_id_char:               'o',
+  note:                      'note_',
+  note_ref:                  'noteref_',
+  note_astx:                 'note_astx_',
+  note_ref_astx:             'noteref_astx_',
+  note_plus:                 'note_plus_',
+  note_ref_plus:             'noteref_plus_',
   meta_o:                    '〔@',   meta_c: '〕',
+  lv_o_0:                    0,
   lv_o_1:                    1,
   lv_o_2:                    2,
   lv_o_3:                    3,
@@ -174,7 +183,8 @@ Hx={
 #Mx[:sm_subset_o]='∈ '; Mx[:sm_subset_c]='∋ '
 Rx={
   mx_fa_clean:               /#{Mx[:fa_o]}.+?#{Mx[:fa_c]}|#{Mx[:pa_o]}.+?#{Mx[:pa_c]}|#{Mx[:mk_o]}.+?#{Mx[:mk_c]}/,
-  lv:                        /〔([1-9]):(\S*?)〕/,
+  lv:                        /〔([0-9]):(\S*?)〕/,
+  lv_0:                      /#{Mx[:lv_o_0]}(\S*?)#{Mx[:lv_c]}/,
   lv_1:                      /#{Mx[:lv_o_1]}(\S*?)#{Mx[:lv_c]}/,
   lv_2:                      /#{Mx[:lv_o_2]}(\S*?)#{Mx[:lv_c]}/,
   lv_3:                      /#{Mx[:lv_o_3]}(\S*?)#{Mx[:lv_c]}/,
@@ -221,7 +231,7 @@ Px={
   po_subscript_o:            ',{',         po_subscript_c:           '},',
   po_hilite_o:               '*{',         po_hilite_c:              '}*',
   po_monospace_o:            '#{',         po_monospace_c:           '}#',
-  lng_lst: %w[am bg bn br ca cs cy da de el en eo es et eu fi fr ga gl he hi hr hy ia is it ja ko la lo lt lv ml mr nl nn no oc pl pt pt_BR ro ru sa se sk sl sq sr sv ta te th tk tr uk ur us vi zh],
+  lng_lst:                   SiSU_is[:language_list],
   lv1:                       '*',
   lv2:                       '=',
   lv3:                       '=',
@@ -250,8 +260,8 @@ else
   }
 end
 Db={
-  name_prefix:               "SiSU#{SiSU_version_dir}a_",
-  name_prefix_db:            "sisu_#{SiSU_version_dir}a_",
+  name_prefix:               "SiSU#{SiSU_is[:version_dir]}a_",
+  name_prefix_db:            "sisu_#{SiSU_is[:version_dir]}a_",
   col_title:                  800,
   col_title_part:             400,
   col_title_edition:           10,
