@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -235,6 +236,7 @@ module SiSU_DbCreate
             seg             VARCHAR(256) NULL,
             lev_an          VARCHAR(1),
             lev             SMALLINT NULL,
+            lev0            SMALLINT,
             lev1            SMALLINT,
             lev2            SMALLINT,
             lev3            SMALLINT,
@@ -483,9 +485,9 @@ module SiSU_DbCreate
           %{COMMENT ON COLUMN doc_objects.metadata_tid
             IS 'tie to title in metadata_and_text';},
           %{COMMENT ON COLUMN doc_objects.lev_an
-            IS 'doc level A-C 1-6';},
+            IS 'doc level A-D 1-6';},
           %{COMMENT ON COLUMN doc_objects.lev
-            IS 'doc level 1-6 \d\~';},
+            IS 'doc level 0-6 \d\~';},
           %{COMMENT ON COLUMN doc_objects.seg
             IS 'segment name from level number 4 (lv 1)';},
           %{COMMENT ON COLUMN doc_objects.ocn
@@ -510,6 +512,8 @@ module SiSU_DbCreate
             IS 'text object - substantive text: light html markup';},
           %{COMMENT ON COLUMN doc_objects.book_idx
             IS 'book index creation information for paragraph, if provided';},
+          %{COMMENT ON COLUMN doc_objects.lev0
+            IS 'document structure, level number 0';},
           %{COMMENT ON COLUMN doc_objects.lev1
             IS 'document structure, level number 1';},
           %{COMMENT ON COLUMN doc_objects.lev2
