@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -158,6 +159,7 @@ module SiSU_DbDrop
             %{DROP INDEX idx_ocn;},
             %{DROP INDEX idx_digest_clean;},
             %{DROP INDEX idx_digest_all;},
+            %{DROP INDEX idx_lev0;},
             %{DROP INDEX idx_lev1;},
             %{DROP INDEX idx_lev2;},
             %{DROP INDEX idx_lev3;},
