@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -82,6 +83,7 @@ module SiSU_DbIndex
           %{CREATE INDEX idx_ocn ON doc_objects(ocn);},
           %{CREATE INDEX idx_digest_clean ON doc_objects(digest_clean);},
           %{CREATE INDEX idx_digest_all ON doc_objects(digest_all);},
+          %{CREATE INDEX idx_lev0 ON doc_objects(lev0);},
           %{CREATE INDEX idx_lev1 ON doc_objects(lev1);},
           %{CREATE INDEX idx_lev2 ON doc_objects(lev2);},
           %{CREATE INDEX idx_lev3 ON doc_objects(lev3);},
