@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -119,15 +120,18 @@ manually create the database: "#{cX.green}#{@db.db}#{cX.off}" if it does not yet
     end
     def read_sqlite
       begin
-        @conn=@db.sqlite.conn_sqlite3
-      rescue
-      ensure
+        begin
+          require 'sqlite3'
+          @conn=@db.sqlite.conn_sqlite3
+        rescue LoadError
+          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('sqlite3 NOT FOUND (LoadError)')
+        end
       end
     end
     def connect
       case @sql_type
-      when /pg/;     read_psql
-      when /sqlite/; read_sqlite
+      when /pg/     then read_psql
+      when /sqlite/ then read_sqlite
       end
       SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"DBI (#{@sql_type}) #{@opt.mod}",@opt.fno).dbi_title unless @opt.act[:quiet][:set]==:on
       begin
