@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -68,8 +69,12 @@ module  SiSU_DBI_Discrete                               #% database building
     include SiSU_DbDBI
   require_relative 'html_lite_shared'                   # html_lite_shared.rb
     include SiSU_FormatShared
-  require 'fileutils'
-    include FileUtils::Verbose
+  begin
+    require 'fileutils'
+      include FileUtils::Verbose
+  rescue LoadError
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('fileutils NOT FOUND (LoadError)')
+  end
   class SQL
     def initialize(opt)
       SiSU_Env::Load.new('dbi',true).prog
@@ -144,9 +149,12 @@ module  SiSU_DBI_Discrete                               #% database building
     end
     def read_sqlite
       begin
-        @conn=@db.sqlite.conn_sqlite3
-      rescue
-      ensure
+        begin
+          require 'sqlite3'
+          @conn=@db.sqlite.conn_sqlite3
+        rescue LoadError
+          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('sqlite3 not available')
+        end
       end
     end
     def connect
