@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -61,7 +62,11 @@
 =end
 $latex_run=nil
 module SiSU_Viz
-  require 'uri'
+  begin
+    require 'uri'
+  rescue LoadError
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('uri NOT FOUND (LoadError)')
+  end
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
   require_relative 'css'                                # css.rb
@@ -563,8 +568,8 @@ module SiSU_Viz
         if italics_list
           r=italics_list.dup
           x=case r
-          when /\/i$/; 'i'
-          else         ''
+          when /\/i$/ then 'i'
+          else             ''
           end
           r=r.gsub(/^\/(.+?)\/i?/,'\1').
             gsub(/\(/,'(?:') # avoid need to escape use of brackets within regex provided
@@ -584,8 +589,8 @@ module SiSU_Viz
         if bold_list
           r=bold_list.dup
           x=case r
-          when /\/i$/; 'i'
-          else         ''
+          when /\/i$/ then 'i'
+          else             ''
           end
           r.gsub(/^\/(.+?)\/i?/,'\1').
             gsub(/\(/,'(?:') # avoid need to escape use of brackets within regex provided
@@ -1198,12 +1203,12 @@ WOK
     end
     def dimensions
       case @papersize
-      when /a4/;     a4
-      when /letter/; letter
-      when /legal/;  legal
-      when /b5/;     b5
-      when /a5/;     a5
-      else           a4
+      when /a4/     then a4
+      when /letter/ then letter
+      when /legal/  then legal
+      when /b5/     then b5
+      when /a5/     then a5
+      else               a4
       end
     end
   end
