@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -90,9 +91,13 @@ module SiSU_DigestView
           if @opt.act[:verbose_plus][:set]==:on \
           or @opt.act[:maintenance][:set]==:on
             SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"file://#{@md.file.output_path.hash_digest.dir}/#{@md.file.base_filename.hash_digest}").flow
+            end
+          end
+          if SiSU_Env::SystemCall.new.openssl
+            SiSU_DigestView::Source::Scroll.new(@particulars).songsheet
+          else
+            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('*EXITED* hash digests will not run without openssl')
           end
-        end
-        SiSU_DigestView::Source::Scroll.new(@particulars).songsheet
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
@@ -335,17 +340,17 @@ module SiSU_DigestView
         data.each do |t_o|
           if t_o.is==:heading
             x=case t_o.ln
-            when 1; l[1] +=1 #fix Mx[:lv_o]
+            when 1 then l[1] +=1 #fix Mx[:lv_o]
               '  '*0 << ':A'
-            when 2; l[2] +=1 #fix Mx[:lv_o]
+            when 2 then l[2] +=1 #fix Mx[:lv_o]
               '  '*1 << ':B'
-            when 3; l[3] +=1 #fix Mx[:lv_o]
+            when 3 then l[3] +=1 #fix Mx[:lv_o]
               '  '*2 << ':C'
-            when 4; l[4] +=1 #fix Mx[:lv_o]
+            when 4 then l[4] +=1 #fix Mx[:lv_o]
               '  '*3 << '1'
-            when 5; l[5] +=1 #fix Mx[:lv_o]
+            when 5 then l[5] +=1 #fix Mx[:lv_o]
               '  '*4 << '2'
-            when 6; l[6] +=1 #fix Mx[:lv_o]
+            when 6 then l[6] +=1 #fix Mx[:lv_o]
               '  '*5 << '3'
             else nil
             end
@@ -358,12 +363,12 @@ module SiSU_DigestView
         ao_structure_summary("document structure[*]\n")
         [0,1,2,3,4,5,6].each do |y|
           v=case y
-          when 1; ':A'
-          when 2; ':B'
-          when 3; ':C'
-          when 4; '1 '
-          when 5; '2 '
-          when 6; '3 '
+          when 1 then ':A'
+          when 2 then ':B'
+          when 3 then ':C'
+          when 4 then '1 '
+          when 5 then '2 '
+          when 6 then '3 '
           end
           ao_structure_summary("#{v}            = #{l[y]}\n") if l[y] > 0
         end
