@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -60,7 +61,11 @@
 
 =end
 module SiSU_HTML
-  require 'pstore'
+  begin
+    require 'pstore'
+  rescue LoadError
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('pstore NOT FOUND (LoadError)')
+  end
   require_relative 'particulars'                        # particulars.rb
     include SiSU_Particulars
   require_relative 'defaults'                           # defaults.rb
@@ -240,6 +245,7 @@ module SiSU_HTML
       def initialize(md=nil,data='')
         @data,@md=data,md
         @vz=SiSU_Viz::Defaults.new
+        @ocn_html_identifier=SiSU_Env::ProcessingSettings.new(@md).ocn_html_identifier
         @tell=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set]) if @md
       end
       def songsheet #extracts toc for scroll & seg
@@ -258,12 +264,13 @@ module SiSU_HTML
             toc=if dob_toc.is ==:heading \
             || dob.is==:heading_insert
               toc=case dob_toc.ln
-              when 1; SiSU_HTML::Source::Toc.new(@md,dob_toc).level_1
-              when 2; SiSU_HTML::Source::Toc.new(@md,dob_toc).level_2
-              when 3; SiSU_HTML::Source::Toc.new(@md,dob_toc).level_3
-              when 4; SiSU_HTML::Source::Toc.new(@md,dob_toc).level_4
-              when 5; SiSU_HTML::Source::Toc.new(@md,dob_toc).level_5
-              when 6; SiSU_HTML::Source::Toc.new(@md,dob_toc).level_6
+              when 0 then SiSU_HTML::Source::Toc.new(@md,dob_toc).level_0
+              when 1 then SiSU_HTML::Source::Toc.new(@md,dob_toc).level_1
+              when 2 then SiSU_HTML::Source::Toc.new(@md,dob_toc).level_2
+              when 3 then SiSU_HTML::Source::Toc.new(@md,dob_toc).level_3
+              when 4 then SiSU_HTML::Source::Toc.new(@md,dob_toc).level_4
+              when 5 then SiSU_HTML::Source::Toc.new(@md,dob_toc).level_5
+              when 6 then SiSU_HTML::Source::Toc.new(@md,dob_toc).level_6
               else nil
               end
             end
@@ -334,6 +341,29 @@ WOK
         @@toc[:seg_mini] << format_head_toc.mini_concordance
       end
 # <-- not used
+      def level_0
+        dob=@data
+        linkname,link=dob.obj.strip,dob.ocn
+        if link \
+        and link !~/#/ #% keep eye on link
+          SiSU_HTML_Format::ParagraphNumber.new(@md,link)
+        end
+        title=linkname
+        toc={}
+        txt_obj={ txt: title }
+        format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
+        toc[:seg]=format_toc.lev0
+        toc[:seg_mini]=format_toc.mini_lev0
+        title=if dob.ocn ==0 then linkname
+        else
+          @@toc[:scr] <<  '<br />'
+          %{<b><a href="##{@ocn_html_identifier}#{dob.ocn}">#{linkname}</a></b>}
+        end
+        txt_obj={ txt: title }
+        format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
+        toc[:scr]=format_toc.lev0
+        toc
+      end
       def level_1
         dob=@data
         linkname,link=dob.obj.strip,dob.ocn
@@ -341,7 +371,7 @@ WOK
         and link !~/#/ #% keep eye on link
           SiSU_HTML_Format::ParagraphNumber.new(@md,link)
         end
-        title=if dob.obj !~/Metadata/ then linkname
+        title=if dob.obj !~/^Metadata$/ then linkname
         else
           link='metadata'
           %{<b><a href="#{link}#{@md.lang_code_insert}#{Sfx[:html]}">#{linkname}</a></b>}
@@ -369,16 +399,13 @@ WOK
           end
         else
           @@toc[:scr] <<  '<br />'
-          link=(dob.ln) \
-          ? dob.ln
-          : ''
-          %{<b><a href="##{link}">#{linkname}</a></b>}
+          %{<b><a href="##{@ocn_html_identifier}#{dob.ocn}">#{linkname}</a></b>}
         end
         txt_obj={ txt: title }
         format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
-        toc[:scr]=if dob.name =~/^meta/ \
-        and dob.obj =~/Document Information/
-          format_toc.lev0
+        toc[:scr]=if dob.obj =~/^Metadata$/ then ''
+        elsif txt_obj[:txt] =~/<a href="#">/
+          format_toc.lev1.gsub(/<a href="#">|<\/a>/,'')
         else format_toc.lev1
         end
         toc
@@ -400,7 +427,10 @@ WOK
           title=%{#{p_num.goto}#{linkname}</a>}
           txt_obj={ txt: title }
           format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
-          toc[:scr]=format_toc.lev2
+          toc[:scr]=if txt_obj[:txt] =~/<a href="#">/
+            format_toc.lev2.gsub(/<a href="#">|<\/a>/,'')
+          else format_toc.lev2
+          end
         end
         toc
       end
@@ -421,7 +451,10 @@ WOK
           title=%{#{p_num.goto}#{linkname}</a>}
           txt_obj={ txt: title }
           format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
-          toc[:scr]=format_toc.lev3
+          toc[:scr]=if txt_obj[:txt] =~/<a href="#">/
+            format_toc.lev3.gsub(/<a href="#">|<\/a>/,'')
+          else format_toc.lev3
+          end
         end
         toc
       end
@@ -483,7 +516,7 @@ WOK
           }
           f=@md.file.base_filename.html_seg(fnh)
           p_num=SiSU_HTML_Format::ParagraphNumber.new(@md,ocn)
-          lnk_n_txt=%{  <a href="#{f}##{ocn}">
+          lnk_n_txt=%{  <a href="#{f}##{@ocn_html_identifier}#{ocn}">
     #{linkname}
   </a>}
           txt_obj={ txt: lnk_n_txt }
@@ -508,7 +541,7 @@ WOK
           }
           f=@md.file.base_filename.html_seg(fnh)
           p_num=SiSU_HTML_Format::ParagraphNumber.new(@md,ocn)
-          lnk_n_txt=%{  <a href="#{f}##{ocn}">
+          lnk_n_txt=%{  <a href="#{f}##{@ocn_html_identifier}#{ocn}">
   #{linkname}
 </a>}
           txt_obj={ txt: lnk_n_txt }
@@ -563,9 +596,8 @@ WOK
         format_head_toc=SiSU_HTML_Format::HeadToc.new(@md)
         dochead=format_head_toc.head
         dochead=dochead.gsub(/toc\.(html)/,'doc.\1') #kludge
-        ads=SiSU_HTML_Promo::Ad.new(@md)
-        toc_shared << dochead << ads.div.major
-        @segtoc << format_head_toc.head << ads.div.major
+        toc_shared << dochead
+        @segtoc << format_head_toc.head
         if @make.build.html_top_band?
           toc_shared << format_head_toc.scroll_head_navigation_band
         end
@@ -591,7 +623,8 @@ WOK
         toc_shared << format_txt_obj.center_bold
         @segtoc << format_txt_obj.center_bold
         if defined? @md.creator.author
-          creator_endnote=@md.creator.author.gsub(/(\*+)/,
+          creator=SiSU_HTML_Tune::CleanHTML.new(@md.creator.author).clean_for_html
+          creator_endnote=creator.gsub(/(\*+)/,
             %{&nbsp;<sup><a href="#notes">\\1</a></sup>})
           tmp_head=creator_endnote + "\n"
           txt_obj={ txt: tmp_head }
@@ -628,8 +661,7 @@ WOK
         #Segtoc tail added here
         @segtoc << "</p>\n" #bugfix sort later DEBUGNOW
         @segtoc << @seg_toc_band_bottom
-        ads=SiSU_HTML_Promo::Ad.new(@md)
-        @segtoc << format_head_toc.seg_navigation_tail << ads.div.close << ads.display << format_head_toc.html_close
+        @segtoc << format_head_toc.seg_navigation_tail << format_head_toc.html_close
         @segtoc=@segtoc.flatten.compact #watch
         if @md.opt.act[:html_seg][:set]==:on
           SiSU_HTML::Source::Output.new(@segtoc,@md).segtoc
