@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -65,30 +66,36 @@ module SiSU_HTML_Format
     def initialize(md,ocn)
       @md,@ocn=md,ocn.to_s
       @ocn ||=''
+      @ocn_html_identifier=SiSU_Env::ProcessingSettings.new(@md).ocn_html_identifier
+      @make=SiSU_Env::ProcessingSettings.new(@md)
     end
     def ocn_display
-      make=SiSU_Env::ProcessingSettings.new(@md)
-      if make.build.ocn?
-        ocn_class='ocn'
+      if @make.build.ocn?
         if @ocn.to_i==0 \
         or @ocn.empty?
-          %{<label class="ocn_off">&nbsp;</label>}
+          ''
         else
+          name=(@make.build.html_strict?) ? '' :  %{ name="#{@ocn}"}
           @ocn.gsub(/^(\d+|)$/,
-            %{<label class="#{ocn_class}"><a name="#{@ocn}" href="##{@ocn}" class="lnk#{ocn_class}">\\1</a></label>})
+            %{<label class="ocn"><a#{name} href="##{@ocn_html_identifier}#{@ocn}" class="lnkocn">\\1</a></label>})
         end
       else
-        %{<label class="ocn_off">&nbsp;</label>}
+        ''
       end
     end
     def name
-      (@ocn==nil || @ocn.empty?) ? '' : %{<a name="#{@ocn}"></a>}
+      if @make.build.html_strict? \
+      or @ocn==(nil || @ocn.empty?)
+        ''
+      else
+        %{<a name="#{@ocn}"></a>}
+      end
     end
     def id #w3c? "tidy" complains about numbers as identifiers ! annoying
       (@ocn==nil || @ocn.empty?) ? '' : %{id="o#{@ocn}"}
     end
     def goto
-      (@ocn==nil || @ocn.empty?) ? '' : %{<a href="##{@ocn}">}
+      (@ocn==nil || @ocn.empty?) ? '' : %{<a href="##{@ocn_html_identifier}#{@ocn}">}
     end
   end
   class HeadInformation
@@ -270,24 +277,6 @@ module SiSU_HTML_Format
       else ''
       end
     end
-    def pdf #retired 2.7.9
-      pdf=if @md.programs[:pdf] \
-      and @cf_defaults.cf_0 =~/p/
-        %{
-<td align="center" bgcolor=#{@vz.color_band2}>
-  <a href="#{Xx[:html_relative1]}pdf/#{@file.base_filename.pdf_p}" target="_top">
-    #{@vz.nav_txt_pdf_portrait}
-  </a>
-</td>
-<td align="center" bgcolor=#{@vz.color_band2}>
-  <a href="#{Xx[:html_relative1]}pdf/#{@file.base_filename.pdf_l}" target="_top">
-    #{@vz.nav_txt_pdf_landscape}
-  </a>
-</td>
-}
-      else ''
-      end
-    end
   end
   class XML
   end
@@ -513,7 +502,8 @@ WOK
     end
     def rights
       def all
-        rights=@md.rights.all.gsub(/^\s*Copyright\s+\(C\)/,'Copyright <sup>&copy;</sup>&nbsp;')
+        rights=SiSU_HTML_Tune::CleanHTML.new(@md.rights.all).clean_for_html
+        rights=rights.gsub(/^\s*Copyright\s+\(C\)/,'Copyright <sup>&copy;</sup>&nbsp;')
         %{<p class="small_left">Rights: #{rights}</p>
 <p />}
       end
@@ -647,8 +637,6 @@ WOK
     def initialize(md)
       super(md)
     end
-    def title_banner(title,subtitle,creator)
-    end
     def dot_control_pre_next
       pre="#{@seg_name_html[@seg_name_html_tracker-1]}#{@md.lang_code_insert}#{Sfx[:html]}"
       up=@toc
@@ -893,6 +881,7 @@ WOK
     attr_accessor :md,:t_o,:txt,:ocn,:format,:table,:link,:linkname,:paranum,:p_num,:headname,:banner,:url
     def initialize(md,t_o)
       @md,@t_o=md,t_o
+      @make=SiSU_Env::ProcessingSettings.new(@md)
       if t_o.is_a?(Hash)
         @txt            =t_o[:txt]            || nil
         @ocn            =t_o[:ocn]            || nil
@@ -916,19 +905,19 @@ WOK
           p caller
         end
       end
-      @headnamed= (@headname ? %{<a name="h#{@headname}" id="h#{@headname}"></a>} : nil)
+      @headnamed=(@headname ? %{<a id="h#{@headname}"></a>} : nil)
       if @txt and not @txt.empty?
         @txt=@txt.gsub(/#{Mx[:mk_o]}[-~]##{Mx[:mk_c]}/,'')
       end
       @p_num=ParagraphNumber.new(@md,@ocn)
       @vz=SiSU_Viz::Defaults.new
-      @make=SiSU_Env::ProcessingSettings.new(@md)
     end
     def nametags_scroll(dob)
       tags=''
       if defined? dob.tags \
       and dob.tags.length > 0 # insert tags "hypertargets"
         dob.tags.each do |t|
+          t=t.gsub(/[^a-z0-9._-]/,'') #use for all html tags? consider limiting to strict? or implementing earlier
           tags=tags << %{<named id="#{t}" />}
         end
       end
@@ -939,7 +928,16 @@ WOK
       if defined? dob.tags \
       and dob.tags.length > 0 # insert tags "hypertargets"
         dob.tags.each do |t|
-          tags=tags << %{<a name="#{t}" ></a>}
+          t=t.gsub(/[^a-z0-9._-]/,'') #use for all html tags? consider limiting to strict? or implementing earlier
+          if @make.build.html_strict?
+            tags=(t =~/^[#{Mx[:ocn_id_char]}]?[0-9.]+$/) \
+            ? tags             #check what can be sorted in ao
+            : (tags << %{<a name="#{t}" ></a>})
+          else
+            tags=(t =~/^[#{Mx[:ocn_id_char]}][0-9.]+$/) \
+            ? tags             #check what can be sorted in ao
+            : (tags << %{<a name="#{t}" ></a>})
+          end
         end
       end
       tags
@@ -948,8 +946,8 @@ WOK
       hn=if @t_o.is ==:heading \
       and not @t_o.name.empty? #determine use
         hn=(@t_o.is ==:heading) \
-        ? (%{<a name="h#{@t_o.name}" id="h#{@t_o.name}"></a>})
-        : (%{<a name="#{@t_o.name}" id="#{@t_o.name}"></a>})
+        ? (%{<a id="h#{@t_o.name}"></a>})
+        : (%{<a id="#{@t_o.name}"></a>})
       else nil
       end
       hn
@@ -980,7 +978,9 @@ WOK
     end
     def para_form_css(tag,attrib)                                                    # regular paragraphs shaped here
       ul=ulc=''
-      ul,ulc="<ul>\n  ","\n  </ul>" if @tag =~/li/
+      if tag =~/li/
+        ul,ulc="<ul>\n  ","\n  </ul>"
+      end
       %{
 <div class="substance">
   #{@p_num.ocn_display}
@@ -1029,14 +1029,14 @@ WOK
       para_form_css(tag,attrib)
     end
     def heading_normal(tag,attrib)
-      section_break=(tag=~/h[1-4]/) \
+      section_break=(tag=~/h[1-5]/) \
       ? '<br /><hr width=90% /><br />'
       : ''
       %{#{section_break}
 <div class="substance">
   #{@p_num.ocn_display}
   <#{tag} class="#{attrib}" #{@p_num.id}>#{@p_num.name}
-    #{@named}<a name="h#{@headname}">#{@txt}</a>
+    #{@named}#{@txt}
   </#{tag}>
 </div>
 }
@@ -1044,6 +1044,9 @@ WOK
     def heading_body
       heading_normal('p','norm')
     end
+    def heading_body0
+      heading_normal('h1','norm')
+    end
     def heading_body1
       heading_normal('h1','norm')
     end
@@ -1074,6 +1077,9 @@ WOK
 </div>
 }
     end
+    def title_heading0
+      title_heading('h1','tiny')
+    end
     def title_heading1
       title_heading('h1','tiny')
     end
@@ -1144,8 +1150,6 @@ WOK
 #{@vz.table_close}}
     end
     def bold_heading
-      @txt=@txt.gsub(/[1-9]~(\S+)/,'<a name="\1"></a>').
-        gsub(/[1-9]~/,'')
       %{<p class="bold">
     #{@txt}
   </p>
@@ -1238,6 +1242,7 @@ WOK
     end
     def subtoc_lev(tag,attrib)
       @txt=clean(@txt)
+      @ocn_html_identifier=SiSU_Env::ProcessingSettings.new(@md).ocn_html_identifier
       txt=if @txt \
       and @txt =~/<\/?i>|<a\s+name="\S+?">/mi
         @txt.gsub(/<\/?i>|<a\s+name="\S+?">/mi,'') #removes name markers from subtoc, go directly to substantive text
@@ -1246,12 +1251,12 @@ WOK
       note=''
       if txt =~/(#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})/m # had \s* at end
         note=$1
-        note=note.gsub(/[\n\s]+/m,' ')
+        note=note.gsub(/[\s]+/m,' ')
         txt=txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ').
-          gsub(/<a[\n\s]+name="-\d+"[\n\s]+href="#_\d+">&nbsp;<sup>\d+<\/sup>&nbsp;/m,'')
+          gsub(/<a[\s]+name="-\d+"[\s]+href="#_\d+">&nbsp;<sup>\d+<\/sup>&nbsp;/m,'')
       end
       %{<#{tag} class="#{attrib}">
-    <a href="##{@ocn}"><i>#{txt}</i></a> #{note}
+    <a href="##{@ocn_html_identifier}#{@ocn}"><i>#{txt}</i></a> #{note}
   </#{tag}>}
     end
     def subtoc_lev5
@@ -1331,6 +1336,9 @@ WOK
       else ''
       end
     end
+    def lev0 #docinfo
+      lev('h1','toc')
+    end
     def lev1
       lev('h1','toc')
     end
@@ -1349,13 +1357,14 @@ WOK
     def lev6
       lev('h6','toc')
     end
-    def lev0 #docinfo
-      lev('h0','toc')
-    end
     def strip_endnotes(txt)
       txt=txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
       txt
     end
+    def mini_lev0
+      @txt=strip_endnotes(@txt)
+      lev('h1','minitoc')
+    end
     def mini_lev1
       @txt=strip_endnotes(@txt)
       lev('h1','minitoc')
@@ -1381,7 +1390,7 @@ WOK
       lev('h6','minitoc')
     end
     def mini_lev0 #docinfo
-      lev('h0','minitoc')
+      lev('h1','minitoc')
     end
     def mini_tail
   %{
