@@ -9,7 +9,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -70,6 +71,7 @@
       def initialize(md,data)
         @md,@data=md,data
         @pat_strip_heading_name=/<a name="h?\d.*?">(.+?)<\/a>/
+        @ocn_html_identifier=SiSU_Env::ProcessingSettings.new(@md).ocn_html_identifier
         @tell=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set]) if @md
       end
       def songsheet
@@ -88,12 +90,13 @@
               gsub(@pat_strip_heading_name,'\1')
               #gsub(/(.*?)<a name="(\d+)"><\/a>(.*)/,'\1') #2002w42 altered gsub - problematic? - suspect
             toc=case txt.ln
-            when 1; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_1
-            when 2; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_2
-            when 3; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_3
-            when 4; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_4
-            when 5; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_5
-            when 6; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_6
+            when 0 then SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_0
+            when 1 then SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_1
+            when 2 then SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_2
+            when 3 then SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_3
+            when 4 then SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_4
+            when 5 then SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_5
+            when 6 then SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_6
             else
             end
             @toc << toc
@@ -114,6 +117,18 @@
         format_head_toc=SiSU_HTML_Format::HeadToc.new(@d0c)
         @@seg_mini << format_head_toc.mini_concordance
       end
+      def level_0
+        txt=@data
+        if (txt.is ==:heading \
+        || txt.is ==:heading_insert) \
+        && txt.ocn !=0
+          txt.obj=txt.obj.gsub(@pat_strip_heading_name,'\1')
+        end
+        txt_obj={ txt: txt.obj }
+        format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
+        toc_mini=format_toc.mini_lev0
+        toc_mini
+      end
       def level_1
         txt=@data
         if (txt.is ==:heading \
@@ -121,7 +136,7 @@
         && txt.ocn !=0
           txt.obj=txt.obj.gsub(@pat_strip_heading_name,'\1')
         end
-        title=unless txt.obj =~/Document Information/; txt.obj
+        title=unless txt.obj =~/Document Information/ then txt.obj
         else
           link='metadata'
           %{<b><a href="#{link}#{@md.lang_code_insert}#{Sfx[:html]}">#{txt.obj}</a></b>}
@@ -190,7 +205,7 @@
           fn: @@seg_url,
         }
         f=@md.file.base_filename.html_seg(fnh)
-        lnk_n_txt=%{  <a href="#{f}##{txt.ocn}">
+        lnk_n_txt=%{  <a href="#{f}##{@ocn_html_identifier}#{txt.ocn}">
     #{txt.obj}
   </a>}
           txt_obj={ txt: lnk_n_txt }
@@ -209,7 +224,7 @@
           fn: @@seg_url,
         }
         f=@md.file.base_filename.html_seg(fnh)
-        lnk_n_txt=%{  <a href="#{f}##{txt.ocn}">
+        lnk_n_txt=%{  <a href="#{f}##{@ocn_html_identifier}#{txt.ocn}">
     #{txt.obj}
   </a>}
           txt_obj={ txt: lnk_n_txt }
