@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -95,7 +96,7 @@ module SiSU_HTML_Scroll
         end
         if dob.obj =~/^Metadata$/ \
         and dob.lv =='B'
-          dob.obj=dob.obj.gsub(/Metadata/,'')
+          dob.obj=dob.obj.gsub(/Metadata/,'') #dob.obj=''
         end
         if defined? dob.name \
         and dob.name =~/^metadata/ \
@@ -114,7 +115,9 @@ module SiSU_HTML_Scroll
           end
           sto=SiSU_HTML_Format::FormatTextObject.new(@md,dob)
           para_html=if dob.is==:heading
-            x=if dob.ln==1
+            x=if dob.ln==0
+              sto.heading_body0
+            elsif dob.ln==1
               sto.heading_body1
             elsif dob.ln==2
               sto.heading_body2
@@ -131,7 +134,11 @@ module SiSU_HTML_Scroll
           and dob.from==:markup
             '<br /><hr width=90% /><br />'
           elsif dob.is==:heading_insert
-            x=if dob.ln==1
+            x=if dob.ln==0
+              unless dob.obj.empty?
+                sto.heading_body0
+              end
+            elsif dob.ln==1
               unless dob.obj.empty?
                 sto.heading_body1
               end
@@ -215,8 +222,7 @@ module SiSU_HTML_Scroll
     def tails
       scr_tail=[]
       format_head_scroll=SiSU_HTML_Format::HeadToc.new(@md)
-      ads=SiSU_HTML_Promo::Ad.new(@md)
-      scr_tail << format_head_scroll.scroll_tail << ads.div.close << ads.display << format_head_scroll.html_close
+      scr_tail << format_head_scroll.scroll_tail << format_head_scroll.html_close
       scr_tail
     end
   end
