@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -71,7 +72,11 @@ module SiSU
   require_relative 'defaults'                          # defaults.rb
     include SiSU_Viz
   require_relative 'utils'                             # utils.rb
-  require 'uri'
+  begin
+    require 'uri'
+  rescue LoadError
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('uri NOT FOUND (LoadError)')
+  end
   class HubMaster
     def initialize(argv)
       pwd_the=Dir.pwd
@@ -245,8 +250,12 @@ module SiSU
     end
   end
   class Processing
-    require 'fileutils'
-      include FileUtils
+    begin
+      require 'fileutils'
+        include FileUtils
+    rescue LoadError
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('fileutils NOT FOUND (LoadError)')
+    end
     @@env=nil
     attr_accessor :op
     def initialize(opt)
@@ -308,7 +317,7 @@ module SiSU
         end
         if @opt.act[:txt_asciidoc][:set]==:on          #% --asciidoc
           require_relative 'txt_asciidoc'              #  txt_asciidoc.rb
-          SiSU_Txt_asciiDoc::Source.new(@opt).read
+          SiSU_Txt_AsciiDoc::Source.new(@opt).read
         end
         if @opt.act[:txt_markdown][:set]==:on          #% --markdown
           require_relative 'txt_markdown'              #  txt_markdown.rb
@@ -644,7 +653,11 @@ module SiSU
     end
     def actions
       if @opt.act[:profile][:set]==:on
-        require 'profile'
+        begin
+          require 'profile'
+        rescue LoadError
+          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('profile NOT FOUND (LoadError)')
+        end
       end
       action_on_file_ =if @opt.act[:rsync][:set]==:on \
       && @opt.act[:site_init][:set]==:on
@@ -747,7 +760,7 @@ module SiSU
           STDERR.puts %{requested action requires valid sisu markup file [filename (.sst .ssm)] or wildcard (that includes a valid filename)}
           if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
-            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).mark(:fuchsia)
+            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__).warn(:fuchsia)
           end
         end
       elsif @opt.mod.inspect =~/--query/
