@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -259,76 +260,76 @@ module SiSU_TextTranslation
     def tex_name(char)
       @lang=if char
         case char
-        when 'sq';    'albanian'
-        when 'am';    'amharic'
-       #when 'ar';    'arabic'         # see polyglossia
-        when 'hy';    'armenian'
-       #when '';      'asturian'       # polyglossia
-       #when '';      'bahasai'        # polyglossia
-       #when '';      'bahasam'        # polyglossia
-        when 'eu';    'basque'
-        when 'bn';    'bengali'
-        when 'pt_BR'; 'brazilian'
-        when 'br';    'breton'
-        when 'bg';    'bulgarian'
-        when 'ca';    'catalan'        # see polyglossia
-       #when '';      'coptic'         # polyglossia
-        when 'hr';    'croatian'
-        when 'cs';    'czech'
-        when 'da';    'danish'
-       #when '';      'divehi'         # polyglossia
-        when 'nl';    'dutch'          # see polyglossia
-        when 'en';    'english'        # see polyglossia
-        when 'eo';    'esperanto'      # see polyglossia
-        when 'et';    'estonian'
-        when 'gl';    'galician'
-        when 'de';    'german'
-        when 'el';    'greek'          #gl ?
-        when 'he';    'hebrew'
-        when 'hi';    'hindi'
-        when 'is';    'icelandic'
-        when 'ia';    'interlingua'
-        when 'ga';    'irish'
-        when 'it';    'italian'
-       #when '';      'farsi'          # polyglossia
-        when 'fi';    'finnish'
-        when 'fr';    'french'
-        when 'lo';    'lao'
-        when 'la';    'latin'
-        when 'lv';    'latvian'
-        when 'lt';    'lithuanian'
-       #when '';      'lsorbian'       # polyglossia
-       #when '';      'magyar'         # polyglossia
-        when 'ml';    'malayalam'
-        when 'mr';    'marathi'
-       #when 'hu';    'magyar'
-        when 'no';    'norske'
-        when 'nn';    'nynorsk'
-        when 'oc';    'occitan'
-        when 'pl';    'polish'
-        when 'pt';    'portuges'
-        when 'ro';    'romanian'
-        when 'ru';    'russian'
-        when 'se';    'samin'          #(check sami?)
-        when 'sa';    'sanskrit'
-        when 'sr';    'serbian'
-       #when '';      'scottish'       # polyglossia  (gd (Gaelic (Scots)))
-        when 'sk';    'slovak'
-        when 'sl';    'slovenian'
-        when 'es';    'spanish'
-        when 'sv';    'swedish'
-        when 'ta';    'tamil'
-        when 'te';    'telugu'
-        when 'th';    'thai'
-        when 'tr';    'turkish'
-        when 'tk';    'turkmen'
-        when 'uk';    'ukrainian'
-        when 'ur';    'urdu'
-       #when '';      'usorbian'       # polyglossia
-        when 'vi';    'vietnamese'
-        when 'cy';    'welsh'
-        when 'us';    'USenglish'      # depreciated, see iso-639-2
-        else          'english'
+        when 'sq'    then 'albanian'
+        when 'am'    then 'amharic'
+       #when 'ar'    then 'arabic'         # see polyglossia
+        when 'hy'    then 'armenian'
+       #when ''      then 'asturian'       # polyglossia
+       #when ''      then 'bahasai'        # polyglossia
+       #when ''      then 'bahasam'        # polyglossia
+        when 'eu'    then 'basque'
+        when 'bn'    then 'bengali'
+        when 'pt_BR' then 'brazilian'
+        when 'br'    then 'breton'
+        when 'bg'    then 'bulgarian'
+        when 'ca'    then 'catalan'        # see polyglossia
+       #when ''      then 'coptic'         # polyglossia
+        when 'hr'    then 'croatian'
+        when 'cs'    then 'czech'
+        when 'da'    then 'danish'
+       #when ''      then 'divehi'         # polyglossia
+        when 'nl'    then 'dutch'          # see polyglossia
+        when 'en'    then 'english'        # see polyglossia
+        when 'eo'    then 'esperanto'      # see polyglossia
+        when 'et'    then 'estonian'
+        when 'gl'    then 'galician'
+        when 'de'    then 'german'
+        when 'el'    then 'greek'          #gl ?
+        when 'he'    then 'hebrew'
+        when 'hi'    then 'hindi'
+        when 'is'    then 'icelandic'
+        when 'ia'    then 'interlingua'
+        when 'ga'    then 'irish'
+        when 'it'    then 'italian'
+       #when ''      then 'farsi'          # polyglossia
+        when 'fi'    then 'finnish'
+        when 'fr'    then 'french'
+        when 'lo'    then 'lao'
+        when 'la'    then 'latin'
+        when 'lv'    then 'latvian'
+        when 'lt'    then 'lithuanian'
+       #when ''      then 'lsorbian'       # polyglossia
+       #when ''      then 'magyar'         # polyglossia
+        when 'ml'    then 'malayalam'
+        when 'mr'    then 'marathi'
+       #when 'hu'    then 'magyar'
+        when 'no'    then 'norske'
+        when 'nn'    then 'nynorsk'
+        when 'oc'    then 'occitan'
+        when 'pl'    then 'polish'
+        when 'pt'    then 'portuges'
+        when 'ro'    then 'romanian'
+        when 'ru'    then 'russian'
+        when 'se'    then 'samin'          #(check sami?)
+        when 'sa'    then 'sanskrit'
+        when 'sr'    then 'serbian'
+       #when ''      then 'scottish'       # polyglossia  (gd (Gaelic (Scots)))
+        when 'sk'    then 'slovak'
+        when 'sl'    then 'slovenian'
+        when 'es'    then 'spanish'
+        when 'sv'    then 'swedish'
+        when 'ta'    then 'tamil'
+        when 'te'    then 'telugu'
+        when 'th'    then 'thai'
+        when 'tr'    then 'turkish'
+        when 'tk'    then 'turkmen'
+        when 'uk'    then 'ukrainian'
+        when 'ur'    then 'urdu'
+       #when ''      then 'usorbian'       # polyglossia
+        when 'vi'    then 'vietnamese'
+        when 'cy'    then 'welsh'
+        when 'us'    then 'USenglish'      # depreciated, see iso-639-2
+        else         then 'english'
         end
       else            'english'
       end
