@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -469,7 +470,7 @@ module SiSU_Manifest
           summarize(id,file,pth,rel,url)
         end
         if FileTest.file?(@f.place_file.asciidoc.dir)==true
-          id='asciiDoc text (UTF-8)'
+          id='AsciiDoc text (UTF-8)'
           pth=@f.output_path.asciidoc.dir
           rel=@f.output_path.asciidoc.rel_sm
           url=@f.output_path.asciidoc.url
@@ -828,7 +829,7 @@ WOK
           metadata(id,info)
         end
         if @md.sisu_version
-          id,info=@translate.sisu_version,"#{@md.sisu_version[:project]} #{@md.sisu_version[:version]} #{@md.sisu_version[:date_stamp]} (#{@md.sisu_version[:date]})"
+          id,info=@translate.sisu_version,"#{@md.sisu_version[:project]} #{@md.sisu_version[:version]} #{@md.sisu_version[:date_stamp]} (#{@md.sisu_version[:date]})#{@md.sisu_version[:install_method]}"
           metadata(id,info)
         end
         if @md.ruby_version
