@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -237,10 +238,10 @@ WOK
           times=wrapped.length
           times=78 if times > 78
           @manpage[:body] << case lv
-          when 1;    '.SH ' << wrapped.upcase << break_line << break_line
-          when 2..3; '.SH ' << wrapped.upcase << break_line << break_line
-          when 4;    '.SH ' << wrapped.upcase << break_line << break_line
-          when 5..6; '.SH ' << wrapped.upcase << break_line << break_line
+          when 0    then '.SH ' << wrapped.upcase << break_line << break_line
+          when 1..3 then '.SH ' << wrapped.upcase << break_line << break_line
+          when 4    then '.SH ' << wrapped.upcase << break_line << break_line
+          when 5..6 then '.SH ' << wrapped.upcase << break_line << break_line
           end
         else
           @manpage[:body] << if  wrapped =~/^\.BI\s/ # main text, contents, body KEEP
@@ -339,14 +340,6 @@ WOK
             x=SiSU_ManpageFormat::FormatTextObject.new(@md,dob)
             if dob.is==:heading
               manpage_structure(dob)
-              dob.obj=case dob.ln
-              when 1; x.heading_body1
-              when 2; x.heading_body2
-              when 3; x.heading_body3
-              when 4; x.heading_body4
-              when 5; x.heading_body5
-              when 6; x.heading_body6
-              end
             elsif dob.is==:para
               manpage_structure(dob)
             else
