@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -61,7 +62,11 @@
 
 =end
 module SiSU_Commandline
-  require 'pathname'
+  begin
+    require 'pathname'
+  rescue LoadError
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('pathname NOT FOUND (LoadError)')
+  end
   require_relative 'sysenv'                             # sysenv.rb
   require_relative 'param_make'                         # param_make.rb
   @@sisu_call_origin_path=nil
@@ -493,51 +498,51 @@ module SiSU_Commandline
       unless m.empty?
         m.each do |s|
           case s
-          when /^--(?:color-toggle)$/;                               c=c+'c'
-          when /^--(?:color-off)$/;                                  c=c+'k'
-          when /^--(?:conf|config|configure|init|initialize|init-site)$/;                        c=c+'CC'
-          when /^--(?:ao|dal?|machine|abstraction|abs)$/;               c=c+'m'
-          when /^--(?:txt|text|plaintext)$/;                         c=c+'t'
-          when /^--(?:html)$/;                                       c=c+'h'
-          when /^--(?:html-scroll|html-seg)$/;                       c=c+'H'
+          when /^--(?:color-toggle)$/                                               then c=c+'c'
+          when /^--(?:color-off)$/                                                  then c=c+'k'
+          when /^--(?:conf|config|configure|init|initialize|init-site)$/            then c=c+'CC'
+          when /^--(?:ao|dal?|machine|abstraction|abs)$/                            then c=c+'m'
+          when /^--(?:txt|text|plaintext)$/                                         then c=c+'t'
+          when /^--(?:html)$/                                                       then c=c+'h'
+          when /^--(?:html-scroll|html-seg)$/                                       then c=c+'H'
             mod << s
-          when /^--(?:epub)$/;                                       c=c+'e'
-          when /^--(?:od[ft])$/;                                     c=c+'o'
-          when /^--(?:pdf)$/;                                        c=c+'p'
-          when /^--pdf-(?:a4|a5|b5|legal|letter)$/;                  c=c+'p'
-          when /^--pdf-(?:p|l|portrait|landscape)$/;                 c=c+'L'
-          when /^--pdf-(?:p(?:ortrait)?|l(?:andscape)?)-(?:a4|letter|a5|b5|legal)$/;     c=c+'L'
-          when /^--pdf-(?:a4|letter|a5|b5|legal)-(?:p(?:ortrait)?|l(?:andscape)?)$/;     c=c+'L'
-          when /^--(?:concordance|wordmap)$/;                        c=c+'w'
-          when /^--(?:manpage|man)$/;                                c=c+'i'
-          when /^--(?:texinfo)$/;                                    c=c+'I'
-          when /^--(?:xhtml)$/;                                      c=c+'b'
-          when /^--(?:xml-sax)$/;                                    c=c+'x'
-          when /^--(?:xml-dom)$/;                                    c=c+'X'
-          when /^--(?:images)$/;                                     c=c+'j'
-          when /^--(?:hash-digests)$/;                               c=c+'N'
-          when /^--(?:po4a|pot?)$/;                                  c=c+'P'
-          when /^--(?:termsheet)$/;                                  c=c+'T'
-          when /^--(?:manifest)$/;                                   c=c+'y'
-          when /^--(?:qrcode)$/;                                     c=c+'Q'
-          when /^--(?:sqlite)$/;                                     c=c+'d'
-          when /^--(?:pg|pg?sql|postgresql)$/;                       c=c+'D'
-          when /^--(?:remote|rsync)$/;                               c=c+'R'
-          when /^--(?:scp)$/;                                        c=c+'r'
-          when /^--(?:source)$/;                                     c=c+'s'
-          when /^--(?:sisupod|pod)$/;                                c=c+'S'
-          when /^--(?:git)$/;                                        c=c+'g'
-          when /^--(?:urls)$/;                                       c=c+'U'
-          when /^--(?:zap|delete)$/;                                 c=c+'Z'
-          when /^--(?:sample-search-form)$/;                         c=c+'F'
-          when /^--(?:webserv|webrick)$/;                            c=c+'W'
-          when /^--(?:profile)$/;                                    c=c+'E'
-          when /^--(?:maintenance|keep-processing-files)$/;          c=c+'M'
-          when /^--(?:verbose[=-]3)$/;                               c=c+'VM'
-          when /^--(?:verbose[=-]2|Verbose|VERBOSE)$/;               c=c+'V'
-          when /^--(?:verbose(?:[=-]1)?)$/;                          c=c+'v'
-          when /^--(?:version)$/;                                    c=c+'v'
-          when /^--(?:verbose[=-]0|quiet|silent)$/;                  c=c+'q'
+          when /^--(?:epub)$/                                                       then c=c+'e'
+          when /^--(?:od[ft])$/                                                     then c=c+'o'
+          when /^--(?:pdf)$/                                                        then c=c+'p'
+          when /^--pdf-(?:a4|a5|b5|legal|letter)$/                                  then c=c+'p'
+          when /^--pdf-(?:p|l|portrait|landscape)$/                                 then c=c+'L'
+          when /^--pdf-(?:p(?:ortrait)?|l(?:andscape)?)-(?:a4|letter|a5|b5|legal)$/ then c=c+'L'
+          when /^--pdf-(?:a4|letter|a5|b5|legal)-(?:p(?:ortrait)?|l(?:andscape)?)$/ then c=c+'L'
+          when /^--(?:concordance|wordmap)$/                                        then c=c+'w'
+          when /^--(?:manpage|man)$/                                                then c=c+'i'
+          when /^--(?:texinfo)$/                                                    then c=c+'I'
+          when /^--(?:xhtml)$/                                                      then c=c+'b'
+          when /^--(?:xml-sax)$/                                                    then c=c+'x'
+          when /^--(?:xml-dom)$/                                                    then c=c+'X'
+          when /^--(?:images)$/                                                     then c=c+'j'
+          when /^--(?:hash-digests)$/                                               then c=c+'N'
+          when /^--(?:po4a|pot?)$/                                                  then c=c+'P'
+          when /^--(?:termsheet)$/                                                  then c=c+'T'
+          when /^--(?:manifest)$/                                                   then c=c+'y'
+          when /^--(?:qrcode)$/                                                     then c=c+'Q'
+          when /^--(?:sqlite)$/                                                     then c=c+'d'
+          when /^--(?:pg|pg?sql|postgresql)$/                                       then c=c+'D'
+          when /^--(?:remote|rsync)$/                                               then c=c+'R'
+          when /^--(?:scp)$/                                                        then c=c+'r'
+          when /^--(?:source)$/                                                     then c=c+'s'
+          when /^--(?:sisupod|pod)$/                                                then c=c+'S'
+          when /^--(?:git)$/                                                        then c=c+'g'
+          when /^--(?:urls)$/                                                       then c=c+'U'
+          when /^--(?:zap|delete)$/                                                 then c=c+'Z'
+          when /^--(?:sample-search-form)$/                                         then c=c+'F'
+          when /^--(?:webserv|webrick)$/                                            then c=c+'W'
+          when /^--(?:profile)$/                                                    then c=c+'E'
+          when /^--(?:maintenance|keep-processing-files)$/                          then c=c+'M'
+          when /^--(?:verbose[=-]3)$/                                               then c=c+'VM'
+          when /^--(?:verbose[=-]2|Verbose|VERBOSE)$/                               then c=c+'V'
+          when /^--(?:verbose(?:[=-]1)?)$/                                          then c=c+'v'
+          when /^--(?:version)$/                                                    then c=c+'v'
+          when /^--(?:verbose[=-]0|quiet|silent)$/                                  then c=c+'q'
           else mod << s                                     #mod only contains command modifiers; commands converted to character
           end
         end
@@ -661,9 +666,9 @@ module SiSU_Commandline
           { set: :filetype }
         else { set: :na }
         end
-        act[:ocn]=if mod.inspect =~/"--inc-ocn"/
+        act[:ocn]=if mod.inspect =~/"--ocn"|"--inc-ocn"/
           { bool: true, set: :on }
-        elsif mod.inspect =~/"--(?:exc|no)-ocn"/ \
+        elsif mod.inspect =~/"--no-ocn"|"--exc-ocn"/ \
         || act[:switch][:off].inspect =~/"ocn"/
           { bool: false, set: :off }
         else { bool: true, set: :na }
@@ -764,12 +769,23 @@ module SiSU_Commandline
           { bool: false, set: :off }
         else { bool: true, set: :na }
         end
-        act[:html]=if (cmd =~/h/ \
+        act[:html]=if mod.inspect =~/"--html-strict"/ \
+        or ((cmd =~/h/ || mod.inspect =~/"--html"/) \
+        && mod.inspect =~/"--strict"/)
+          act[:html_strict]={ bool: true, set: :on }
+          act[:html_scroll]={ bool: true, set: :on }
+          act[:html_seg]={ bool: true, set: :on }
+          { bool: true, set: :on }
+        elsif (cmd =~/h/ \
         || mod.inspect =~/"--html"/)
+          act[:html_strict]={ bool: false, set: :off }
           act[:html_scroll]={ bool: true, set: :on }
           act[:html_seg]={ bool: true, set: :on }
           { bool: true, set: :on }
         else
+          act[:html_strict]=(mod.inspect =~/"--strict"/) \
+          ? { bool: true, set: :on }
+          : { bool: false, set: :na }
           act[:html_scroll]=(mod.inspect =~/"--html-scroll"/) \
           ? { bool: true, set: :on }
           : { bool: false, set: :na }
@@ -849,10 +865,20 @@ module SiSU_Commandline
         || mod.inspect =~/"--epub"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
-        act[:odt]=(cmd =~/o/ \
-        || mod.inspect =~/"--odt"|"--odf"/) \
-        ? { bool: true, set: :on }
-        : { bool: false, set: :na }
+        act[:odt]=if cmd =~/o/ \
+        or mod.inspect =~/"--odt"|"--odf"|"--odt-ocn"|"--odf-ocn"/
+          act[:odt_ocn]=if (mod.inspect =~/"--odt-ocn"|"--odf-ocn"/ \
+          or mod.inspect =~/"--ocn"|"--inc-ocn"/)
+            { bool: true, set: :on }
+          elsif mod.inspect =~/"--no-ocn"|"--exc-ocn"/
+            { bool: false, set: :off }
+          else
+            { bool: false, set: :na }
+          end
+          { bool: true, set: :on }
+        else
+          { bool: false, set: :na }
+        end
         act[:xml_sax]=(cmd =~/x/ \
         || mod.inspect =~/"--xml-sax"/) \
         ? { bool: true, set: :on }
@@ -878,10 +904,20 @@ module SiSU_Commandline
         || mod.inspect =~/"--xhtml"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
-        act[:txt]=(cmd =~/[at]/ \
-        || mod.inspect =~/"--txt"/) \
-        ? { bool: true, set: :on }
-        : { bool: false, set: :na }
+        act[:txt]=if cmd =~/[at]/ \
+        or mod.inspect =~/"--txt"|"--text"|"--plaintext"|"--txt-ocn"|"--text-ocn"|"--plaintext-ocn"/
+          act[:txt_ocn]=if (mod.inspect =~/"--txt-ocn"|"--text-ocn"|"--plaintext-ocn"/ \
+          or mod.inspect =~/"--ocn"|"--inc-ocn"/)
+            { bool: true, set: :on }
+          elsif mod.inspect =~/"--no-ocn"|"--exc-ocn"/
+            { bool: false, set: :off }
+          else
+            { bool: false, set: :na }
+          end
+          { bool: true, set: :on }
+        else
+          { bool: false, set: :na }
+        end
         act[:txt_textile]=(mod.inspect =~/"--textile"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
