@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -150,8 +151,8 @@ module SiSU_MarkupType
       end
       def series
         s=case identify.version[:determined].to_s
-        when /^[01]\./; '1.0'
-        when /^[2]\./; '2.0'
+        when /^[01]\./ then '1.0'
+        when /^[2]\./  then '2.0'
         else '2.0'
         end
         "series #{s}"
