@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -146,17 +147,18 @@ module SiSU_Param_Make
         x=@h['headings']
         x=((x =~/;/) ? (x.split(/;\s*/)) : [ x ])
         lv[0]=x
-        lv1=x[0] ||='1~ '                                                                                     #some arbitrary changes made
+        lv0 ||='A~ '             #root level, single document apex, document title
+        lv1=x[0] ||='B~ '
         lv[1]=/^#{lv1}/
-        lv2=x[1] ||='2~ '
+        lv2=x[1] ||='C~ '
         lv[2]=/^#{lv2}/
-        lv3=x[2] ||='3~ '
+        lv3=x[2] ||='D~ '
         lv[3]=/^#{lv3}/
-        lv4=x[3] ||='4~ '
+        lv4=x[3] ||='1~ '
         lv[4]=/^#{lv4}/
-        lv5=x[4] ||='5~ '
+        lv5=x[4] ||='2~ '
         lv[5]=/^#{lv5}/
-        lv6=x[5] ||='6~ '
+        lv6=x[5] ||='3~ '
         lv[6]=/^#{lv6}/
         lv
       end
