@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -820,13 +821,13 @@ GSUB
             @p_num=SiSU_Po4aUtils::ParagraphNumber.new(paranum)
           end
           case dob_src.is
-          when :heading; pot_structure_heading(dob_src,notes_s,dob_trn,notes_t)
-          when :para;    pot_structure_para(dob_src,notes_s,dob_trn,notes_t)
-          when :group;   pot_structure_group(dob_src,notes_s,dob_trn,notes_t)
-          when :block;   pot_structure_block(dob_src,notes_s,dob_trn,notes_t)
-          when :verse;   pot_structure_verse(dob_src,notes_s,dob_trn,notes_t)
-          when :code;    pot_structure_code(dob_src,notes_s,dob_trn,notes_t)
-          when :table;   pot_structure_table(dob_src,notes_s,dob_trn,notes_t)
+          when :heading then pot_structure_heading(dob_src,notes_s,dob_trn,notes_t)
+          when :para    then pot_structure_para(dob_src,notes_s,dob_trn,notes_t)
+          when :group   then pot_structure_group(dob_src,notes_s,dob_trn,notes_t)
+          when :block   then pot_structure_block(dob_src,notes_s,dob_trn,notes_t)
+          when :verse   then pot_structure_verse(dob_src,notes_s,dob_trn,notes_t)
+          when :code    then pot_structure_code(dob_src,notes_s,dob_trn,notes_t)
+          when :table   then pot_structure_table(dob_src,notes_s,dob_trn,notes_t)
           end
           if defined? dob_src.idx \
           and not dob_src.idx.nil? \
