@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -111,8 +112,12 @@ module SiSU_Remote
       @tell=lambda { SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@msg,"#{@msgs.inspect if @msgs}") }
     end
     def fns
-      require 'open-uri'
-      require 'pp'
+      begin
+        require 'open-uri'
+        require 'pp'
+      rescue LoadError
+        SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('open-uri or pp NOT FOUND (LoadError)')
+      end
       require_relative 'composite'                      # composite.rb
       @rgx_image=/(?:^|[^_\\])\{\s*(\S+?\.(?:png|jpg|gif))/
       threads=[]
@@ -157,7 +162,11 @@ module SiSU_Remote
     def sisupod
       get_p=@get_s
       if get_p.length > 0                                     #% remote sisupod
-         require 'net/http'
+        begin
+          require 'net/http'
+        rescue LoadError
+          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('net/http NOT FOUND (LoadError)')
+        end
         for requested_pod in get_p
           pod_info=RemoteDownload.new(requested_pod)
           Net::HTTP.start(pod_info.pod.site) do |http|
