@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -207,7 +208,11 @@ module SiSU_TextRepresentation
       end
       @env ||=SiSU_Env::InfoEnv.new(@md.fns)
       @sha_ =((@env.digest.type =='sha256') ? true : false)
-      @sha_ ? (require 'digest/sha2') : (require 'digest/md5')
+      begin
+        @sha_ ? (require 'digest/sha2') : (require 'digest/md5')
+      rescue LoadError
+        SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error((@sha_ ? 'digest/sha2' : 'digest/md5') + ' NOT FOUND')
+      end
     end
     def digest(txt)
       d=nil
