@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -63,8 +64,12 @@
 module SiSU_sstFromXML
   require_relative 'sysenv'                             # sysenv.rb
   class Convert
-    require 'rexml/document'
-      include REXML
+    begin
+      require 'rexml/document'
+        include REXML
+    rescue LoadError
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('rexml/document NOT FOUND (LoadError)')
+    end
     def initialize(opt)
       @opt=opt
       @sisu,@sisu_base=[],[]
