@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -106,7 +107,7 @@ module SiSU_TexInfo
         tool=(@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
         || @opt.act[:maintenance][:set]==:on) \
-        ?  "#{@env.program.texinfo} #{@md.file.output_path.texinfo.dir}/#{@md.file.base_filename.info}"
+        ? "cd #{@md.file.output_path.texinfo.dir} && #{@env.program.texinfo} #{@md.file.base_filename.info}; cd -"
         : "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
         (@opt.act[:verbose][:set]==:on \
         || @opt.act[:verbose_plus][:set]==:on \
@@ -271,7 +272,7 @@ module SiSU_TexInfo
       @submenu,@subsubmenu={},{}
       data.each do |dob|
         if dob.is ==:heading \
-        && (dob.ln.to_s =~ /^[1-3]$/)
+        && (dob.ln.to_s =~ /^[0-3]$/)
           toc=SiSU_TexInfoFormat::Texinfo.new(@md,dob)
           texinfo_menu << toc.menu
         elsif dob.is ==:heading \
@@ -307,32 +308,37 @@ module SiSU_TexInfo
       @@do_submenu,@@do_subsubmenu=1,1
       data_new=[]
       data.each do |dob|
-        mono=SiSU_TexInfoFormat::Texinfo.new(@md,dob)
+        unless defined? dob.ln and dob.ln == (5..6)
+          mono=SiSU_TexInfoFormat::Texinfo.new(@md,dob)
+        end
         if dob.is==:heading
           case dob.ln
-          when 1; dob=mono.level1
-          when 2; dob=mono.level2
-          when 3; dob=mono.level3
+          when 0 then dob=mono.level0
+          when 1 then dob=mono.level1
+          when 2 then dob=mono.level2
+          when 3 then dob=mono.level3
           when 4;
+            @@n4_txt=dob.obj
             dob=mono.level4
             n_menu+=1
             @@do_submenu,@@do_subsubmenu=1,1
           when 5;
             n_submenu+=1
             @@do_subsubmenu=1
+            @@n5_txt=dob.obj
             if @@do_submenu==1
               menu=SiSU_TexInfoFormat::TeXinfoTxt.new(@md,dob,@submenu[n_menu])
-              dob.obj="#{menu.submenu}#{mono.level5.obj}"
+              dob.obj="#{menu.submenu}#{SiSU_TexInfoFormat::Texinfo.new(@md,dob,@@n4_txt).level5.obj}"
               @@do_submenu=0
-            else dob=mono.level5
+            else dob.obj="#{SiSU_TexInfoFormat::Texinfo.new(@md,dob,@@n4_txt).level5.obj}"
             end
           when 6;
             if @@do_submenu==1
               menu=SiSU_TexInfoFormat::TeXinfoTxt.new(@md,dob,@submenu[n_menu])
+              dob.obj="#{menu.submenu}#{SiSU_TexInfoFormat::Texinfo.new(@md,dob,@@n5_txt).level6.obj}"
               dob.obj="#{menu.subsubmenu}#{mono.level6.obj}"
               @@do_subsubmenu=0
-            else
-              dob=mono.level6
+            else dob.obj="#{SiSU_TexInfoFormat::Texinfo.new(@md,dob,@@n5_txt).level6.obj}"
             end
           end
         else
@@ -340,8 +346,9 @@ module SiSU_TexInfo
             dob.obj=nil
           else
             if dob.is==:para \
-            && (dob.obj !~/##{dob.ocn}/)
-              dob.obj="#{dob.obj} ##{dob.ocn}"
+            && (dob.obj !~/#{Dx[:ocn_o]}#{dob.ocn}#{Dx[:ocn_c]}/)
+              dob.obj=dob.ocn.is_a?(Fixnum) \
+              ? "#{dob.obj} #{Dx[:ocn_o]}#{dob.ocn}#{Dx[:ocn_c]}\n\n" : "#{dob.obj}\n\n"
             end
           end
         end
@@ -411,7 +418,9 @@ module SiSU_TexInfo
           FileUtils::mkdir_p(@f.output_path.texinfo.dir)
         end
         info_src=%{#{@env.processing_path.texi}/#{@md.fnb}.info}
-        FileUtils::cp(info_src, @f.place_file.info.dir)
+        Dir.glob("#{info_src}*").sort.each do |f|
+          FileUtils::cp(f, File.dirname(@f.place_file.info.dir)) # bug should provide dir without need to extract it!
+        end
       end
     end
   end
