@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -60,7 +61,11 @@
 
 =end
 module SiSU_TeX
-  require 'pstore'
+  begin
+    require 'pstore'
+  rescue LoadError
+    SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('pstore NOT FOUND (LoadError)')
+  end
   require_relative 'defaults'                           # defaults.rb
     include SiSU_Viz
   require_relative 'particulars'                        # particulars.rb
@@ -77,7 +82,11 @@ module SiSU_TeX
   @@n=@@tableheader=@@rights=nil
   @@date ||=SiSU_Env::InfoDate.new
   class Source
-    require 'pstore'
+    begin
+      require 'pstore'
+    rescue LoadError
+      SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('pstore NOT FOUND (LoadError)')
+    end
     require_relative 'sysenv'                           # sysenv.rb
       include SiSU_Env
     include SiSU_Viz
@@ -116,10 +125,10 @@ module SiSU_TeX
         || @opt.act[:maintenance][:set]==:on)
           @env.url.output_tell
           if @md.opt.act[:pdf_l][:set]==:on
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}pdf").flow
+            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}#{@md.papersize_array[0]}.pdf").flow
           end
           if @md.opt.act[:pdf_p][:set]==:on
-            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@opt.fns} #{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}pdf").flow
+            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{@opt.fns} #{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}#{@md.papersize_array[0]}.pdf").flow
           end
         end
         @md=@particulars.md
@@ -214,12 +223,12 @@ module SiSU_TeX
           landscape_pdf="#{pwd}/#{tex_fn_base}.landscape.pdf"
         end
         case papersize
-        when /a4/;     pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
-        when /a5/;     pdf_p=@f.pdf_p_a5;     pdf_l=@f.pdf_l_a5
-        when /b5/;     pdf_p=@f.pdf_p_b5;     pdf_l=@f.pdf_l_b5
-        when /letter/; pdf_p=@f.pdf_p_letter; pdf_l=@f.pdf_l_letter
-        when /legal/;  pdf_p=@f.pdf_p_legal;  pdf_l=@f.pdf_l_legal
-        else           pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
+        when /a4/     then pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
+        when /a5/     then pdf_p=@f.pdf_p_a5;     pdf_l=@f.pdf_l_a5
+        when /b5/     then pdf_p=@f.pdf_p_b5;     pdf_l=@f.pdf_l_b5
+        when /letter/ then pdf_p=@f.pdf_p_letter; pdf_l=@f.pdf_l_letter
+        when /legal/  then pdf_p=@f.pdf_p_legal;  pdf_l=@f.pdf_l_legal
+        else               pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
         end
         FileUtils::mkdir_p(@md.file.output_path.pdf.dir) unless FileTest.directory?(@md.file.output_path.pdf.dir)
         cX=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set]).cX
@@ -269,7 +278,7 @@ module SiSU_TeX
                         and File.size(texfile) > 0
                           #@tex_f_no+=1
                         else
-                          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).mark("\tzero file size #{@env.processing_path.tex}/#{texfile}")
+                          SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error("\tzero file size #{@env.processing_path.tex}/#{texfile}")
                         end
                       end
                     end
@@ -278,12 +287,12 @@ module SiSU_TeX
               end
             end
             case @md.papersize_array[0] #default pdf
-            when /a4/;     pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
-            when /a5/;     pdf_p=@f.pdf_p_a5;     pdf_l=@f.pdf_l_a5
-            when /b5/;     pdf_p=@f.pdf_p_b5;     pdf_l=@f.pdf_l_b5
-            when /letter/; pdf_p=@f.pdf_p_letter; pdf_l=@f.pdf_l_letter
-            when /legal/;  pdf_p=@f.pdf_p_legal;  pdf_l=@f.pdf_l_legal
-            else           pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
+            when /a4/     then pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
+            when /a5/     then pdf_p=@f.pdf_p_a5;     pdf_l=@f.pdf_l_a5
+            when /b5/     then pdf_p=@f.pdf_p_b5;     pdf_l=@f.pdf_l_b5
+            when /letter/ then pdf_p=@f.pdf_p_letter; pdf_l=@f.pdf_l_letter
+            when /legal/  then pdf_p=@f.pdf_p_legal;  pdf_l=@f.pdf_l_legal
+            else               pdf_p=@f.pdf_p_a4;     pdf_l=@f.pdf_l_a4
             end
             if @md.opt.act[:pdf_p][:set]==:on
               if FileTest.file?("#{@md.file.output_path.pdf.dir}/#{pdf_p}")
@@ -364,7 +373,7 @@ module SiSU_TeX
           elsif @md.opt.act[:pdf_p][:set]==:on
             'pdfTex portrait'
           else
-            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).mark('error: neither landscape nor portrait')
+            SiSU_Utils::CodeMarker.new(__LINE__,__FILE__,:fuchsia).error('error: neither landscape nor portrait')
           end
           if (@md.opt.act[:verbose][:set]==:on \
           || @md.opt.act[:verbose_plus][:set]==:on \
