@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -133,11 +134,11 @@ module SiSU_TeX_Pdf
       row_break='\\\\\\'
       if @dob.is==:table
         tw=case @dob.tmp[:paper_size]
-        when /a4/i;      @tx.a4.landscape.w     #European default, SiSU default
-        when /letter/i;  @tx.letter.landscape.w #U.S. default
-        when /legal/i;   @tx.legal.landscape.w  #U.S. alternative
-        when /book|b5/i; @tx.b5.landscape.w     #book default - larger
-        when /a5/i;      @tx.a5.landscape.w
+        when /a4/i      then @tx.a4.landscape.w     #European default, SiSU default
+        when /letter/i  then @tx.letter.landscape.w #U.S. default
+        when /legal/i   then @tx.legal.landscape.w  #U.S. alternative
+        when /book|b5/i then @tx.b5.landscape.w     #book default - larger
+        when /a5/i      then @tx.a5.landscape.w
         else             @tx.a4.landscape.w     #default currently A4
         end
         textwidth=(tw.to_i/2) - 24
@@ -178,11 +179,11 @@ module SiSU_TeX_Pdf
       row_break='\\\\\\'
       if @dob.is==:table
         tw=case @dob.tmp[:paper_size]
-        when /a4/i;      @tx.a4.portrait.w     #European default, SiSU default
-        when /letter/i;  @tx.letter.portrait.w #U.S. default
-        when /legal/i;   @tx.legal.portrait.w  #U.S. alternative
-        when /book|b5/i; @tx.b5.portrait.w     #book default - larger
-        when /a5/i;      @tx.a5.portrait.w
+        when /a4/i      then @tx.a4.portrait.w     #European default, SiSU default
+        when /letter/i  then @tx.letter.portrait.w #U.S. default
+        when /legal/i   then @tx.legal.portrait.w  #U.S. alternative
+        when /book|b5/i then @tx.b5.portrait.w     #book default - larger
+        when /a5/i      then @tx.a5.portrait.w
         else             @tx.a4.portrait.w     #default currently A4
         end
         textwidth=tw.to_i - 20
@@ -311,163 +312,163 @@ module SiSU_TeX_Pdf
       case @dob.indent
       when /0/
         case @dob.hang
-        when /0/; indent,hang='0mm', '0mm'
-        when /1/; indent,hang='0mm','10mm'
-        when /2/; indent,hang='0mm','20mm'
-        when /3/; indent,hang='0mm','30mm'
-        when /4/; indent,hang='0mm','40mm'
-        when /5/; indent,hang='0mm','50mm'
-        when /6/; indent,hang='0mm','60mm'
-        when /7/; indent,hang='0mm','70mm'
-        when /8/; indent,hang='0mm','80mm'
-        when /9/; indent,hang='0mm','90mm'
+        when /0/ then indent,hang='0mm', '0mm'
+        when /1/ then indent,hang='0mm','10mm'
+        when /2/ then indent,hang='0mm','20mm'
+        when /3/ then indent,hang='0mm','30mm'
+        when /4/ then indent,hang='0mm','40mm'
+        when /5/ then indent,hang='0mm','50mm'
+        when /6/ then indent,hang='0mm','60mm'
+        when /7/ then indent,hang='0mm','70mm'
+        when /8/ then indent,hang='0mm','80mm'
+        when /9/ then indent,hang='0mm','90mm'
         end
       when /1/
         case @dob.hang
-        when /0/; indent,hang='10mm','-10mm'
-        when /1/; indent,hang='10mm',  '0mm'
-        when /2/; indent,hang='10mm', '10mm'
-        when /3/; indent,hang='10mm', '20mm'
-        when /4/; indent,hang='10mm', '30mm'
-        when /5/; indent,hang='10mm', '40mm'
-        when /6/; indent,hang='10mm', '50mm'
-        when /7/; indent,hang='10mm', '60mm'
-        when /8/; indent,hang='10mm', '70mm'
-        when /9/; indent,hang='10mm', '80mm'
+        when /0/ then indent,hang='10mm','-10mm'
+        when /1/ then indent,hang='10mm',  '0mm'
+        when /2/ then indent,hang='10mm', '10mm'
+        when /3/ then indent,hang='10mm', '20mm'
+        when /4/ then indent,hang='10mm', '30mm'
+        when /5/ then indent,hang='10mm', '40mm'
+        when /6/ then indent,hang='10mm', '50mm'
+        when /7/ then indent,hang='10mm', '60mm'
+        when /8/ then indent,hang='10mm', '70mm'
+        when /9/ then indent,hang='10mm', '80mm'
         end
       when /2/
         case @dob.hang
-        when /0/; indent,hang='20mm','-20mm'
-        when /1/; indent,hang='20mm','-10mm'
-        when /2/; indent,hang='20mm',  '0mm'
-        when /3/; indent,hang='20mm', '10mm'
-        when /4/; indent,hang='20mm', '20mm'
-        when /5/; indent,hang='20mm', '30mm'
-        when /6/; indent,hang='20mm', '40mm'
-        when /7/; indent,hang='20mm', '50mm'
-        when /8/; indent,hang='20mm', '60mm'
-        when /9/; indent,hang='20mm', '70mm'
+        when /0/ then indent,hang='20mm','-20mm'
+        when /1/ then indent,hang='20mm','-10mm'
+        when /2/ then indent,hang='20mm',  '0mm'
+        when /3/ then indent,hang='20mm', '10mm'
+        when /4/ then indent,hang='20mm', '20mm'
+        when /5/ then indent,hang='20mm', '30mm'
+        when /6/ then indent,hang='20mm', '40mm'
+        when /7/ then indent,hang='20mm', '50mm'
+        when /8/ then indent,hang='20mm', '60mm'
+        when /9/ then indent,hang='20mm', '70mm'
         end
       when /3/
         case @dob.hang
-        when /0/; indent,hang='30mm','-30mm'
-        when /1/; indent,hang='30mm','-20mm'
-        when /2/; indent,hang='30mm','-10mm'
-        when /3/; indent,hang='30mm',  '0mm'
-        when /4/; indent,hang='30mm', '10mm'
-        when /5/; indent,hang='30mm', '20mm'
-        when /6/; indent,hang='30mm', '30mm'
-        when /7/; indent,hang='30mm', '40mm'
-        when /8/; indent,hang='30mm', '50mm'
-        when /9/; indent,hang='30mm', '60mm'
+        when /0/ then indent,hang='30mm','-30mm'
+        when /1/ then indent,hang='30mm','-20mm'
+        when /2/ then indent,hang='30mm','-10mm'
+        when /3/ then indent,hang='30mm',  '0mm'
+        when /4/ then indent,hang='30mm', '10mm'
+        when /5/ then indent,hang='30mm', '20mm'
+        when /6/ then indent,hang='30mm', '30mm'
+        when /7/ then indent,hang='30mm', '40mm'
+        when /8/ then indent,hang='30mm', '50mm'
+        when /9/ then indent,hang='30mm', '60mm'
         end
       when /4/
         case @dob.hang
-        when /0/; indent,hang='40mm','-40mm'
-        when /1/; indent,hang='40mm','-30mm'
-        when /2/; indent,hang='40mm','-20mm'
-        when /3/; indent,hang='40mm','-10mm'
-        when /4/; indent,hang='40mm',  '0mm'
-        when /5/; indent,hang='40mm', '10mm'
-        when /6/; indent,hang='40mm', '20mm'
-        when /7/; indent,hang='40mm', '30mm'
-        when /8/; indent,hang='40mm', '40mm'
-        when /9/; indent,hang='40mm', '50mm'
+        when /0/ then indent,hang='40mm','-40mm'
+        when /1/ then indent,hang='40mm','-30mm'
+        when /2/ then indent,hang='40mm','-20mm'
+        when /3/ then indent,hang='40mm','-10mm'
+        when /4/ then indent,hang='40mm',  '0mm'
+        when /5/ then indent,hang='40mm', '10mm'
+        when /6/ then indent,hang='40mm', '20mm'
+        when /7/ then indent,hang='40mm', '30mm'
+        when /8/ then indent,hang='40mm', '40mm'
+        when /9/ then indent,hang='40mm', '50mm'
         end
       when /5/
         case @dob.hang
-        when /0/; indent,hang='50mm','-50mm'
-        when /1/; indent,hang='50mm','-40mm'
-        when /2/; indent,hang='50mm','-30mm'
-        when /3/; indent,hang='50mm','-20mm'
-        when /4/; indent,hang='50mm','-10mm'
-        when /5/; indent,hang='50mm',  '0mm'
-        when /6/; indent,hang='50mm', '10mm'
-        when /7/; indent,hang='50mm', '20mm'
-        when /8/; indent,hang='50mm', '30mm'
-        when /9/; indent,hang='50mm', '40mm'
+        when /0/ then indent,hang='50mm','-50mm'
+        when /1/ then indent,hang='50mm','-40mm'
+        when /2/ then indent,hang='50mm','-30mm'
+        when /3/ then indent,hang='50mm','-20mm'
+        when /4/ then indent,hang='50mm','-10mm'
+        when /5/ then indent,hang='50mm',  '0mm'
+        when /6/ then indent,hang='50mm', '10mm'
+        when /7/ then indent,hang='50mm', '20mm'
+        when /8/ then indent,hang='50mm', '30mm'
+        when /9/ then indent,hang='50mm', '40mm'
         end
       when /6/
         case @dob.hang
-        when /0/; indent,hang='60mm','-60mm'
-        when /1/; indent,hang='60mm','-50mm'
-        when /2/; indent,hang='60mm','-40mm'
-        when /3/; indent,hang='60mm','-30mm'
-        when /4/; indent,hang='60mm','-20mm'
-        when /5/; indent,hang='60mm','-10mm'
-        when /6/; indent,hang='60mm',  '0mm'
-        when /7/; indent,hang='60mm', '10mm'
-        when /8/; indent,hang='60mm', '20mm'
-        when /9/; indent,hang='60mm', '30mm'
+        when /0/ then indent,hang='60mm','-60mm'
+        when /1/ then indent,hang='60mm','-50mm'
+        when /2/ then indent,hang='60mm','-40mm'
+        when /3/ then indent,hang='60mm','-30mm'
+        when /4/ then indent,hang='60mm','-20mm'
+        when /5/ then indent,hang='60mm','-10mm'
+        when /6/ then indent,hang='60mm',  '0mm'
+        when /7/ then indent,hang='60mm', '10mm'
+        when /8/ then indent,hang='60mm', '20mm'
+        when /9/ then indent,hang='60mm', '30mm'
         end
       when /7/
         case @dob.hang
-        when /0/; indent,hang='70mm','-70mm'
-        when /1/; indent,hang='70mm','-60mm'
-        when /2/; indent,hang='70mm','-50mm'
-        when /3/; indent,hang='70mm','-40mm'
-        when /4/; indent,hang='70mm','-30mm'
-        when /5/; indent,hang='70mm','-20mm'
-        when /6/; indent,hang='70mm','-10mm'
-        when /7/; indent,hang='70mm',  '0mm'
-        when /8/; indent,hang='70mm', '10mm'
-        when /9/; indent,hang='70mm', '20mm'
+        when /0/ then indent,hang='70mm','-70mm'
+        when /1/ then indent,hang='70mm','-60mm'
+        when /2/ then indent,hang='70mm','-50mm'
+        when /3/ then indent,hang='70mm','-40mm'
+        when /4/ then indent,hang='70mm','-30mm'
+        when /5/ then indent,hang='70mm','-20mm'
+        when /6/ then indent,hang='70mm','-10mm'
+        when /7/ then indent,hang='70mm',  '0mm'
+        when /8/ then indent,hang='70mm', '10mm'
+        when /9/ then indent,hang='70mm', '20mm'
         end
       when /8/
         case @dob.hang
-        when /0/; indent,hang='80mm','-80mm'
-        when /1/; indent,hang='80mm','-70mm'
-        when /2/; indent,hang='80mm','-60mm'
-        when /3/; indent,hang='80mm','-50mm'
-        when /4/; indent,hang='80mm','-40mm'
-        when /5/; indent,hang='80mm','-30mm'
-        when /6/; indent,hang='80mm','-20mm'
-        when /7/; indent,hang='80mm','-10mm'
-        when /8/; indent,hang='80mm',  '0mm'
-        when /9/; indent,hang='80mm', '10mm'
+        when /0/ then indent,hang='80mm','-80mm'
+        when /1/ then indent,hang='80mm','-70mm'
+        when /2/ then indent,hang='80mm','-60mm'
+        when /3/ then indent,hang='80mm','-50mm'
+        when /4/ then indent,hang='80mm','-40mm'
+        when /5/ then indent,hang='80mm','-30mm'
+        when /6/ then indent,hang='80mm','-20mm'
+        when /7/ then indent,hang='80mm','-10mm'
+        when /8/ then indent,hang='80mm',  '0mm'
+        when /9/ then indent,hang='80mm', '10mm'
         end
       when /9/
         case @dob.hang
-        when /0/; indent,hang='90mm','-90mm'
-        when /1/; indent,hang='90mm','-80mm'
-        when /2/; indent,hang='90mm','-70mm'
-        when /3/; indent,hang='90mm','-60mm'
-        when /4/; indent,hang='90mm','-50mm'
-        when /5/; indent,hang='90mm','-40mm'
-        when /6/; indent,hang='90mm','-30mm'
-        when /7/; indent,hang='90mm','-20mm'
-        when /8/; indent,hang='90mm','-10mm'
-        when /9/; indent,hang='90mm',  '0mm'
+        when /0/ then indent,hang='90mm','-90mm'
+        when /1/ then indent,hang='90mm','-80mm'
+        when /2/ then indent,hang='90mm','-70mm'
+        when /3/ then indent,hang='90mm','-60mm'
+        when /4/ then indent,hang='90mm','-50mm'
+        when /5/ then indent,hang='90mm','-40mm'
+        when /6/ then indent,hang='90mm','-30mm'
+        when /7/ then indent,hang='90mm','-20mm'
+        when /8/ then indent,hang='90mm','-10mm'
+        when /9/ then indent,hang='90mm',  '0mm'
         end
       end
       "\\begin{ParagraphHang}{#{indent}}{#{hang}}#{@dob.tmp} \\end{ParagraphHang}}"
     end
     def indent
       indent=case @dob.indent
-      when /1/; '0mm'
-      when /2/; '10mm'
-      when /3/; '20mm'
-      when /4/; '30mm'
-      when /5/; '40mm'
-      when /6/; '50mm'
-      when /7/; '60mm'
-      when /8/; '70mm'
-      when /9/; '80mm'
+      when /1/ then '0mm'
+      when /2/ then '10mm'
+      when /3/ then '20mm'
+      when /4/ then '30mm'
+      when /5/ then '40mm'
+      when /6/ then '50mm'
+      when /7/ then '60mm'
+      when /8/ then '70mm'
+      when /9/ then '80mm'
       end
       "\\begin{ParagraphIndent}{#{indent}}#{@dob.tmp} \\end{ParagraphIndent}}"
     end
     def bullet
       blt=if @dob.indent
         indent=case @dob.indent
-        when /1/; '0em'
-        when /2/; '1.0em'
-        when /3/; '2.0em'
-        when /4/; '3.0em'
-        when /5/; '4.0em'
-        when /6/; '5.0em'
-        when /7/; '6.0em'
-        when /8/; '7.0em'
-        when /9/; '8.0em'
+        when /1/ then '0em'
+        when /2/ then '1.0em'
+        when /3/ then '2.0em'
+        when /4/ then '3.0em'
+        when /5/ then '4.0em'
+        when /6/ then '5.0em'
+        when /7/ then '6.0em'
+        when /8/ then '7.0em'
+        when /9/ then '8.0em'
         else      '-1.0em'
         end
         "\\begin{Bullet}{#{indent}}$\\txtbullet$\\hspace{\\enspace}#{@dob.tmp}\\end{Bullet}"
@@ -816,9 +817,9 @@ module SiSU_TeX_Pdf
         @md.make.texpdf_font.cjk
       else
         case @md.opt.lng
-        when /zh/; @env.font.texpdf.cjk_zh
-        when /ja/; @env.font.texpdf.cjk_ja
-        when /ko/; @env.font.texpdf.cjk_ko
+        when /zh/ then @env.font.texpdf.cjk_zh
+        when /ja/ then @env.font.texpdf.cjk_ja
+        when /ko/ then @env.font.texpdf.cjk_ko
         else @env.font.texpdf.cjk
         end
       end
@@ -1497,7 +1498,7 @@ module SiSU_TeX_Pdf
       v=SiSU_Env::InfoVersion.instance.get_version
       base_prog_txt=if @md.base_program
         case @md.base_program
-        when /kdissert/i; "\n\\\\ This document prepared using \\href{http://freehackers.org/~tnagy/kdissert/}{Kdissert \\ http://freehackers.org/~tnagy/kdissert/ } \\\\ Kdissert is Document Mapping software by Thomas Nagy"
+        when /kdissert/i then "\n\\\\ This document prepared using \\href{http://freehackers.org/~tnagy/kdissert/}{Kdissert \\ http://freehackers.org/~tnagy/kdissert/ } \\\\ Kdissert is Document Mapping software by Thomas Nagy"
         else ''
         end
       else ''
