@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -59,7 +60,7 @@
  ** Description: plaintext (smarttext) generation, asciidoc
 
 =end
-module SiSU_Txt_asciiDoc
+module SiSU_Txt_AsciiDoc
   require_relative 'ao'                                 # ao.rb
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
@@ -89,8 +90,8 @@ module SiSU_Txt_asciiDoc
           (@opt.act[:verbose][:set]==:on \
           || @opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on) \
-          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'asciiDoc (plaintext utf-8)',tool).green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'asciiDoc (plaintext utf-8)',tool).green_title_hi
+          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'AsciiDoc (plaintext utf-8)',tool).green_hi_blue
+          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'AsciiDoc (plaintext utf-8)',tool).green_title_hi
           if (@opt.act[:verbose_plus][:set]==:on \
           || @opt.act[:maintenance][:set]==:on)
             SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"#{md.file.output_path.asciidoc.dir}/#{md.file.base_filename.asciidoc}").flow
@@ -106,7 +107,7 @@ module SiSU_Txt_asciiDoc
         else 78
         end
         #wrap_width=(defined? md.make.plaintext_wrap) ? md.make.plaintext_wrap : 78
-        SiSU_Txt_asciiDoc::Source::Scroll.new(md,ao_array,wrap_width).songsheet
+        SiSU_Txt_AsciiDoc::Source::Scroll.new(md,ao_array,wrap_width).songsheet
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
@@ -126,9 +127,9 @@ module SiSU_Txt_asciiDoc
         @brace_url=SiSU_Viz::Defaults.new.url_decoration
         @tab="\t"
         @@endnotes_=case md.opt.mod.inspect
-        when /--footnote/; false
-        when /--endnote/; true
-        else true
+        when /--footnote/ then false
+        when /--endnote/  then true
+        else                   true
         end
         @plaintext={ body: [], open: [], close: [], head: [], metadata: [], tail: [] }
       end
@@ -140,42 +141,6 @@ module SiSU_Txt_asciiDoc
         "\n"
       end
       # Used for extraction of endnotes from paragraphs
-      def extract_endnotes(dob='')
-        notes=dob.obj.scan(/(?:#{Mx[:en_a_o]}|#{Mx[:en_b_o]})([\d*+]+\s+.+?)(?:#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/)
-        @n=[]
-        notes.flatten.each do |n| #high cost to deal with <br> appropriately within plaintext, consider
-          n=n.dup.to_s
-          if n =~/#{Mx[:br_line]}|#{Mx[:br_nl]}/
-            fix = n.split(/#{Mx[:br_line]}|#{Mx[:br_nl]}/) #watch #added
-            fix.each do |x|
-              unless x.empty?; @n << x
-              end
-            end
-          else                 @n << n
-          end
-        end
-        notes=@n.flatten
-        notes.each do |e|
-          util=(e.to_s =~/^\[[\d*+]+\]:/) \
-          ? (SiSU_TextUtils::Wrap.new(e.to_s,@wrap_width,4,1))
-          : (SiSU_TextUtils::Wrap.new(e.to_s,@wrap_width,1,1))
-          wrap=util.line_wrap
-          wrap=if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
-            wrap.gsub(/^(\s*)([\d*+]+)\s+(.+?)\s*\Z/m, <<-GSUB
-\\1[\\2]: \\3
-              GSUB
-            )
-          else
-            wrap.gsub(/^(.+)\Z/m, <<-GSUB
-\\1
-              GSUB
-            )
-          end
-          @@endnotes[:para] << "-#{wrap}"
-          @@endnotes[:end] << '' << wrap
-        end
-        @@endnotes
-      end
       def plaintext_metadata
         array=SiSU_Metadata::Summary.new(@md).plaintext.metadata
         array.each do |meta|
@@ -220,6 +185,9 @@ WOK
       def decorate
         def heading
           def inline
+            def l0
+              '='
+            end
             def l1
               '=='
             end
@@ -235,12 +203,12 @@ WOK
             def l5
               '' #'======' #logical
             end
-            def l6
-              '' #'=======' #logical
-            end
             self
           end
           def underscore
+            def l0
+              '='
+            end
             def l1
               '-'
             end
@@ -254,10 +222,7 @@ WOK
               '+'
             end
             def l5
-              '' #'.' #proposed
-            end
-            def l6
-              '' #'.' #proposed
+              '.' #'.' #proposed
             end
             self
           end
@@ -367,6 +332,7 @@ WOK
       def heading_decorated_inline(dob)
         if dob.is==:heading
           heading_inline = case dob.lc
+          when 0 then decorate.heading.inline.l0
           when 1 then decorate.heading.inline.l1
           when 2 then decorate.heading.inline.l2
           when 3 then decorate.heading.inline.l3
@@ -381,6 +347,7 @@ WOK
         if dob.is==:heading
           #times=@wrap_width if times > @wrap_width
           case dob.lc
+          when 0 then decorate.heading.underscore.l0*times + p_num << break_line*2
           when 1 then decorate.heading.underscore.l1*times + p_num << break_line*2
           when 2 then decorate.heading.underscore.l2*times + p_num << break_line*2
           when 3 then decorate.heading.underscore.l3*times + p_num << break_line*2
@@ -470,7 +437,8 @@ WOK
               gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,'\1 [link: <\2>]').
               gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}image/,'\1 [link: local image]').
               gsub(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,"#{@brace_url.txt_open}\\1#{@brace_url.txt_close}")
-            extract_endnotes(dob)
+            dob.obj=dob.obj.gsub(/\s*#{Mx[:en_a_o]}([\d*+]+)\s+(.+?)#{Mx[:en_a_c]}/,' footnote:[note\1,\2]').
+              gsub(/\s*#{Mx[:en_b_o]}([\d*+]+\s+.+?)#{Mx[:en_b_c]}/,' footnote:[\1]')
             dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'[^\1]'). # endnote marker marked up
               gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'[^\1]'). # endnote marker marked up
               gsub(/#{Mx[:gl_o]}(?:#lt|#060)#{Mx[:gl_c]}/,'<').
@@ -518,7 +486,7 @@ WOK
               @plaintext[:body] << dob.obj + p_num << break_line
             elsif dob.is==:break
               sp=' '
-              ln='-'
+              ln='<' #ln='-'
               @plaintext[:body] <<=if dob.obj==Mx[:br_page] \
               or dob.obj==Mx[:br_page_new] \
               or dob.obj==Mx[:br_page_line]
