@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -126,9 +127,9 @@ module SiSU_Txt_Markdown
         @brace_url=SiSU_Viz::Defaults.new.url_decoration
         @tab="\t"
         @@endnotes_=case md.opt.mod.inspect
-        when /--footnote/; false
-        when /--endnote/; true
-        else true
+        when /--footnote/ then false
+        when /--endnote/  then true
+        else                   true
         end
         @plaintext={ body: [], open: [], close: [], head: [], metadata: [], tail: [] }
       end
@@ -220,22 +221,22 @@ WOK
       def decorate
         def heading
           def inline                   #atx
-            def l1
+            def l0
               '#'
             end
-            def l2
+            def l1
               '##'
             end
-            def l3
+            def l2
               '###'
             end
-            def l4
+            def l3
               '####'
             end
-            def l5
+            def l4
               '#####'
             end
-            def l6
+            def l5
               '######'
             end
             self
@@ -367,6 +368,7 @@ WOK
       def heading_decorated_inline(dob)
         if dob.is==:heading
           heading_inline = case dob.lc
+          when 0 then decorate.heading.inline.l0
           when 1 then decorate.heading.inline.l1
           when 2 then decorate.heading.inline.l2
           when 3 then decorate.heading.inline.l3
@@ -381,6 +383,7 @@ WOK
         if dob.is==:heading
           #times=@wrap_width if times > @wrap_width
           case dob.lc
+          when 0 then decorate.heading.underscore.l0*times + p_num << break_line*2
           when 1 then decorate.heading.underscore.l1*times + p_num << break_line*2
           when 2 then decorate.heading.underscore.l2*times + p_num << break_line*2
           when 3 then decorate.heading.underscore.l3*times + p_num << break_line*2
