@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -126,9 +127,9 @@ module SiSU_Txt_Textile
         @brace_url=SiSU_Viz::Defaults.new.url_decoration
         @tab="\t"
         @@endnotes_=case md.opt.mod.inspect
-        when /--footnote/; false
-        when /--endnote/; true
-        else true
+        when /--footnote/ then false
+        when /--endnote/  then true
+        else                   true
         end
         @plaintext={ body: [], open: [], close: [], head: [], metadata: [], tail: [] }
       end
@@ -220,22 +221,22 @@ WOK
       def decorate
         def heading
           def inline
-            def l1
+            def l0
               'h1. '
             end
-            def l2
+            def l1
               'h2. '
             end
-            def l3
+            def l2
               'h3. '
             end
-            def l4
+            def l3
               'h4. '
             end
-            def l5
+            def l4
               'h5. '
             end
-            def l6
+            def l5
               'h6. '
             end
             self
@@ -345,12 +346,13 @@ WOK
       end
       def heading_decorated_inline(dob)
         heading_inline = case dob.lc
-        when 1;      decorate.heading.inline.l1
-        when 2;      decorate.heading.inline.l2
-        when 3;      decorate.heading.inline.l3
-        when 4;      decorate.heading.inline.l4
-        when 5;      decorate.heading.inline.l5
-        when 6;      decorate.heading.inline.l6
+        when 0 then decorate.heading.inline.l0
+        when 1 then decorate.heading.inline.l1
+        when 2 then decorate.heading.inline.l2
+        when 3 then decorate.heading.inline.l3
+        when 4 then decorate.heading.inline.l4
+        when 5 then decorate.heading.inline.l5
+        when 6 then decorate.heading.inline.l6
         end
         heading_inline + ' ' +  dob.obj
       end
