@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -115,7 +116,7 @@ module SiSU_Urls
         'S --sisupod (sisupod)'=>@fn[:sisupod],
         't --txt (Plain-text (endnotes))'=>@fn[:plain],
         '  --textile (textile txt)'=>@fn[:txt_textile],
-        '  --asciidoc (asciidoc txt)'=>@fn[:txt_asciidoc],
+        '  --asciidoc (AsciiDoc txt)'=>@fn[:txt_asciidoc],
         '  --markdown (markdown txt)'=>@fn[:txt_markdown],
         '  --rst (rST restructured-text)'=>@fn[:txt_rst],
         '  --docbook-book (DocBook Book)'=>@fn[:xml_docbook_book],
@@ -197,10 +198,10 @@ module SiSU_Urls
       end
       def pdf
         def portrait(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}pdf").result
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}#{@md.papersize_array[0]}.pdf").result
         end
         def landscape(x)
-          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}pdf").result
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}#{@md.papersize_array[0]}.pdf").result
         end
         self
       end
@@ -208,7 +209,7 @@ module SiSU_Urls
         SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","#{@prog.manpage_viewer} #{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}").result
       end
       def pinfo(x,y)
-        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","pinfo -f #{@md.file.output_path.texinfo.dir}/#{@md.file.base_filename.info}").result
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"[#{@opt.f_pth[:lng_is]}] -#{x}","cd #{@md.file.output_path.texinfo.dir} && #{@env.program.texinfo} #{@md.file.base_filename.info}; cd -").result
       end
       def po4a
         def po(x,y)
