@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -222,10 +223,10 @@ WOK
         para.gsub!(/<\S+?>#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}/,'') # endnote marker marked up
         if lv
           @@wiki[:body] << case lv
-          when 1;      '='*2 << para.strip  << @br*2
-          when 2..3;   '='*2 << para.strip  << @br*2
-          when 4;      '='*4 << para.strip  << @br*2
-          when 5..6;   '='*4 << para.strip  << @br*2
+          when 1    then '='*2 << para.strip << @br*2
+          when 2..3 then '='*2 << para.strip << @br*2
+          when 4    then '='*4 << para.strip << @br*2
+          when 5..6 then '='*4 << para.strip << @br*2
           end
         else @@wiki[:body] << para << @br*2 # main text, contents, body KEEP
         end
