@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -316,12 +317,13 @@ WOK
               if dob.is==:heading
                 xml_structure(dob)
                 dob.obj=case dob.ln
-                when 1; x.heading_body1
-                when 2; x.heading_body2
-                when 3; x.heading_body3
-                when 4; x.heading_body4
-                when 5; x.heading_body5
-                when 6; x.heading_body6
+                when 0 then x.heading_body0
+                when 1 then x.heading_body1
+                when 2 then x.heading_body2
+                when 3 then x.heading_body3
+                when 4 then x.heading_body4
+                when 5 then x.heading_body5
+                when 6 then x.heading_body6
                 end
               else
                 if dob.is ==:verse
