@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -1225,7 +1226,7 @@ module SiSU_XHTML_EPUB2_Format
         x=x.gsub(/&nbsp;/,' ') if Ep[:alt]==:on
         x.gsub(/&/,'&amp;').
           gsub(/</,"&lt;").gsub(/>/,"&gt;").
-          gsub(/#{Dx[:url_o]}/,Dx[:url_o_xml]).gsub(/#{Dx[:url_c]}/,Dx[:url_o_xml]).
+          gsub(/#{Dx[:url_o]}/,Dx[:url_o_xml]).gsub(/#{Dx[:url_c]}/,Dx[:url_c_xml]).
           #gsub(/</,'&#60;').gsub(/>/,'&#62;').
           gsub(/\\\\/,'<br />').
           gsub(/&lt;br(?: \/)?&gt;/,'<br />')
@@ -1305,6 +1306,7 @@ application/epub+zip
       dir_epub_cont=@md.env.processing_path.epub + '/' + Ep[:d_oebps]
       segfilename=dir_epub_cont + '/' + name
       output_epub_cont_seg=File.new(segfilename,'w')
+      txt=dob.obj.gsub(/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]}/,'')
       output_epub_cont_seg << %{#{doc_type}
   <head>
     <title>
@@ -1319,7 +1321,7 @@ application/epub+zip
       <div class="substance">
         <label class="ocn"><a href="#o#{dob.ocn}" class="lnkocn">#{dob.ocn}</a></label>
         <h1 class="norm" id="o#{dob.ocn}">
-          #{dob.obj}
+          #{txt}
         </h1>
       </div>
     </div>
@@ -1360,12 +1362,13 @@ output_epub_cont_seg.close
         depth=@md.lvs[1] + @md.lvs[2] + @md.lvs[3] + @md.lvs[4]
         title=SanitizeXML.xml(@md.title.full)
         author=SanitizeXML.xml(@md.author)
+        dgst=(@md.dgst.is_a?(Array) and @md.dgst.length > 1) ? @md.dgst[1] : 'na'
         <<-WOK
     <!-- four required metadata items (for all NCX documents,
       (including the relaxed constraints of OPS 2.0) -->
     <title>#{title} by #{author}</title>
     <link href="css/xhtml.css" rel="stylesheet" type="text/css" id="main-css" />
-    <meta name="dtb:uid" content="urn:uuid:#{@md.dgst[1]}" />
+    <meta name="dtb:uid" content="urn:uuid:#{dgst}" />
     <!-- <meta name="epub-creator" content="#{@md.publisher}" /> -->
     <meta name="dtb:depth" content="#{depth}" />
     <meta name="dtb:totalPageCount" content="0" />
@@ -1412,15 +1415,16 @@ output_epub_cont_seg.close
         WOK
       end
       def navpoint(dob,no,fn_base,hashtag=nil)
-         fn=fn_base + Sfx[:epub_xhtml]
-         name=hashtag ? fn + hashtag : fn
+        fn=fn_base + Sfx[:epub_xhtml]
+        name=hashtag ? fn + hashtag : fn
         id_u=DISABLE[:epub][:ncx_navpoint_unique_id] \
         ? ''
         : "-#{no}"
+        txt=dob.obj.gsub(/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]}/,'')
         <<-WOK
       <navPoint class="chapter" id="navpoint#{id_u}" playOrder="#{no}">
         <navLabel>
-          <text>#{dob.obj}</text>
+          <text>#{txt}</text>
         </navLabel>
         <content src="#{name}" />
         WOK
@@ -1576,18 +1580,19 @@ output_epub_cont_seg.close
         else ''
         end
         f=SiSU_Env::FileOp.new(@md)
+        dgst=(@md.dgst.is_a?(Array) and @md.dgst.length > 1) ? @md.dgst[1] : 'na'
         <<-WOK
   <#{$ep[:o]}metadata
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xmlns:opf="http://www.idpf.org/2007/opf"
     xmlns:dcterms="http://purl.org/dc/terms/"
     xmlns:dc="http://purl.org/dc/elements/1.1/"
-    unique-identifier="urn:uuid:#{@md.dgst[1]}" version="2.0">
+    unique-identifier="urn:uuid:#{dgst}" version="2.0">
     <dc:title>#{@md.title.full}</dc:title>
     #{cover_image}#{author}#{editor}#{translator}#{illustrator}#{language}#{date_published}#{subject}#{rights}
     <dc:identifier opf:scheme="URI">#{f.output_path.epub.url.gsub(/http:\/\//,'')}/#{f.base_filename.epub}</dc:identifier>
-    <dc:identifier id="bookid">urn:uuid:#{@md.dgst[1]}</dc:identifier>
-    <!-- <dc:identifier id="EPB-UUID">urn:uuid:#{@md.dgst[1]}</dc:identifier> -->
+    <dc:identifier id="bookid">urn:uuid:#{dgst}</dc:identifier>
+    <!-- <dc:identifier id="EPB-UUID">urn:uuid:#{dgst}</dc:identifier> -->
   </#{$ep[:o]}metadata>
         WOK
       end
@@ -1988,6 +1993,11 @@ output_epub_cont_seg.close
 </div>
 }
     end
+    def title_heading0
+      DISABLE[:epub][:per_section_title] \
+      ? ''
+      : title_heading('h1','tiny')
+    end
     def title_heading1
       DISABLE[:epub][:per_section_title] \
       ? ''
@@ -2124,10 +2134,10 @@ output_epub_cont_seg.close
       note=''
       if txt =~/(#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})/m # had \s* at end
         note=$1
-        note=note.gsub(/[\n\s]+/m,' ')
+        note=note.gsub(/[\s]+/m,' ')
         txt=txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ').
-          gsub(/<a[\n\s]+"[\n\s]+href="#note_ref\d+">#{$ep[:hsp]}<sup id="note\d+">\d+<\/sup>#{$ep[:hsp]}/m,'').
-          gsub(/<a[\n\s]+"[\n\s]+href="#note_ref\d+">#{$ep[:hsp]}<sup id="note\d+">\d+<\/sup>#{$ep[:hsp]}/m,'') #remove
+          gsub(/<a[\n\s]+"[\n\s]+href="##{Mx[:note_ref]}\d+">#{$ep[:hsp]}<sup id="#{Mx[:note]}\d+">\d+<\/sup>#{$ep[:hsp]}/m,'').
+          gsub(/<a[\n\s]+"[\n\s]+href="##{Mx[:note_ref]}\d+">#{$ep[:hsp]}<sup id="#{Mx[:note]}\d+">\d+<\/sup>#{$ep[:hsp]}/m,'') #remove
       end
       %{<#{tag} class="#{attrib}">
     <a href="#o#{@ocn}"><i>#{txt}</i></a> #{note}
