@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -123,8 +124,8 @@ WOK
     @@seg_name,@@seg_name_xhtml=[],[]
     @@seg_url=@@fn=@@get_hash_to=@@get_hash_fn=''
     @@loop_count=@@seg_total=@@tracker=0
-    @@is4=@@is3=@@is2=@@is1=0
-    @@heading1=@@heading2=@@heading3=@@heading4=0
+    @@is4=@@is3=@@is2=@@is1=@@is0=0
+    @@heading0=@@heading1=@@heading2=@@heading3=@@heading4=0
     @@seg[:headings],@@seg[:main],@@seg[:idx],@@seg[:tail],@@seg_subtoc_array,@@seg_endnotes_array,@@seg[:endnote_all]=Array.new(7){[]}
     @@seg[:heading_endnotes]=''
     @@tablehead,@@number_of_cols=0,0
@@ -154,7 +155,7 @@ WOK
   protected
     def articles(data)
       tracking,newfile=0,0
-      @@is4=@@is3=@@is2=@@is1=0
+      @@is4=@@is3=@@is2=@@is1=@@is0=0
       printed_endnote_seg='n'
       idx_xhtml=nil
       if @md.book_idx
@@ -195,35 +196,38 @@ WOK
         #end
         if (dob.is==:heading \
         || dob.is==:heading_insert) \
-        and dob.ln==4
-          if dob.ocn==0
-            @@heading4=dob.obj
-          else @@heading4=dob.obj
-          end
+        && dob.ln==4
+          @@heading4=dob.obj
           @@is4=newfile=1
         end
         if (dob.is==:heading \
         || dob.is==:heading_insert) \
-        and dob.ln==3
+        && dob.ln==3
           @@heading3=dob.obj
           @@is4,@@is3=0,1
         end
         if (dob.is==:heading \
         || dob.is==:heading_insert) \
-        and dob.ln==2
+        && dob.ln==2
           @@heading2=dob.obj
           @@is4,@@is3,@@is2=0,0,1
         end
         if (dob.is==:heading \
         || dob.is==:heading_insert) \
-        and dob.ln==1
+        && dob.ln==1
           @@heading1=dob.obj
           @@is4,@@is3,@@is2,@@is1=0,0,0,1
         end
-        if (@@is1 && !@@is2 && !@@is3 && !@@is4)
+        if (dob.is==:heading \
+        || dob.is==:heading_insert) \
+        && dob.ln==0
+          @@heading0=dob.obj
+          @@is4,@@is3,@@is2,@@is1,@@is0=0,0,0,0,1
+        end
+        if (@@is0 && !@@is1 && !@@is2 && !@@is3 && !@@is4)
           if not (dob.is==:heading \
           || dob.is==:heading_insert) \
-          and dob.ln==1
+          && dob.ln==0
             $_ #; check
           end
         end
@@ -234,7 +238,7 @@ WOK
             newfile=0
             if (dob.is==:heading \
             || dob.is==:heading_insert) \
-            and dob.ln==4
+            && dob.ln==4
               if tracking != 0
                 SiSU_XHTML_EPUB2_Seg::Seg.new(@md).tail
                 segfilename="#{dir_epub_cont}/#{@@seg_name_xhtml[tracking-1]}#{Sfx[:epub_xhtml]}"
@@ -274,8 +278,8 @@ WOK
           end
           if (dob.is==:heading \
           || dob.is==:heading_insert) \
-          and dob.ln==4 \
-          and dob.name
+          && dob.ln==4 \
+          && dob.name
             @@get_hash_to=dob.name
             @@get_hash_fn=dob.name
           end
@@ -301,15 +305,19 @@ WOK
     def head(dob)
       clean=/<!.*?!>|<:.*?>$/
       @p_num ||= ''
-      if @@is1==1
+      if @@is0==1
         if defined? @md.creator.author \
         and @md.creator.author
           @author=%{<b>#{@md.creator.author}</b>\n}
         end
-        ocn=(@@heading1[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]) \
-        ? $1
-        : ''
-        @p_num=SiSU_XHTML_EPUB2_Format::ParagraphNumber.new(@md,ocn)
+        @p_num=SiSU_XHTML_EPUB2_Format::ParagraphNumber.new(@md,dob.ocn)
+        txt_obj={ txt: @@heading0, ocn_display: @p_num.ocn_display }
+        format_seg=SiSU_XHTML_EPUB2_Format::FormatSeg.new(@md,txt_obj)
+        @@seg[:headings] << format_seg.title_heading0.gsub(clean,'')
+        @@heading0=@@heading0.gsub(/#{$ep[:hsp]}<a name="-[\d*+]+" href="#_[\d*+]+">#{$ep[:hsp]}<sup>[\d*+]+<\/sup>#{$ep[:hsp]}<\/a>/,'')
+      end
+      if @@is1==1
+        @p_num=SiSU_XHTML_EPUB2_Format::ParagraphNumber.new(@md,dob.ocn)
         txt_obj={ txt: @@heading1, ocn_display: @p_num.ocn_display }
         format_seg=SiSU_XHTML_EPUB2_Format::FormatSeg.new(@md,txt_obj)
         @@seg[:headings] << format_seg.title_heading1.gsub(clean,'')
@@ -317,10 +325,7 @@ WOK
       end
       if @@is2==1
         heading2=@@heading2
-        ocn=(heading2[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]) \
-        ? $1
-        : ''
-        @p_num=SiSU_XHTML_EPUB2_Format::ParagraphNumber.new(@md,ocn)
+        @p_num=SiSU_XHTML_EPUB2_Format::ParagraphNumber.new(@md,dob.ocn)
         txt_obj={ txt: heading2, ocn_display: @p_num.ocn_display }
         format_seg=SiSU_XHTML_EPUB2_Format::FormatSeg.new(@md,txt_obj)
         @@seg[:headings] << format_seg.title_heading2.gsub(clean,'')
@@ -328,10 +333,7 @@ WOK
       end
       if @@is3==1
         heading3=@@heading3
-        ocn=(heading3[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]) \
-        ? $1
-        : ''
-        @p_num=SiSU_XHTML_EPUB2_Format::ParagraphNumber.new(@md,ocn)
+        @p_num=SiSU_XHTML_EPUB2_Format::ParagraphNumber.new(@md,dob.ocn)
         txt_obj={ txt: heading3, ocn_display: @p_num.ocn_display }
         format_seg=SiSU_XHTML_EPUB2_Format::FormatSeg.new(@md,txt_obj)
         @@seg[:headings] << format_seg.title_heading3.gsub(clean,'')
@@ -339,10 +341,7 @@ WOK
       end
       if @@is4==1
         heading4=@@heading4
-        ocn=(heading4[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]) \
-        ? $1
-        : ''
-        @p_num=SiSU_XHTML_EPUB2_Format::ParagraphNumber.new(@md,ocn)
+        @p_num=SiSU_XHTML_EPUB2_Format::ParagraphNumber.new(@md,dob.ocn)
         txt_obj={ txt: heading4, ocn_display: @p_num.ocn_display }
         format_seg=SiSU_XHTML_EPUB2_Format::FormatSeg.new(@md,txt_obj)
         @@seg[:headings] << format_seg.title_heading4.gsub(clean,'')
@@ -402,7 +401,7 @@ WOK
           sto.break
       end
       if @md.flag_separate_endnotes # may need to revisit, check
-        dob.obj=dob.obj.gsub(/"\s+href="#note_ref(\d+)">/,%{" href=\"endnotes#{Sfx[:epub_xhtml]}#note_ref\\1">})       #endnote- twice #removed file type
+        dob.obj=dob.obj.gsub(/"\s+href="##{Mx[:note_ref]}(\d+)">/,%{" href=\"endnotes#{Sfx[:epub_xhtml]}##{Mx[:note_ref]}\\1">})       #endnote- twice #removed file type
       end
       if (dob.is ==:heading \
       || dob.is==:heading_insert \
