@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -190,11 +191,10 @@ WOK
         n=n1=n2=n3=0
         if dob.is==:heading
           lv=dob.ln
-          n=dob.ln - 1
+          n=dob.ln
           n1=dob.ln
-          n2=dob.ln + 1
-          n3=dob.ln + 2
-          dob.ln - 3
+          n2=dob.ln + 2
+          n3=dob.ln + 3
         else lv=nil
         end
         tag=if defined? dob.name and dob.name=~/\S+/
@@ -373,7 +373,12 @@ WOK
                 format_scroll=SiSU_XML_Format::FormatScroll.new(@md,dob) if dob.is==:para and dob.indent ##FIX
                 x=SiSU_XML_Format::FormatSeg.new(@md,dob)
                 if dob.is==:heading
-                  if dob.ln==1
+                  if dob.ln==0
+                    type="heading_section_#{dob.ln.to_s}"
+                    xml_markup(dob)
+                    xml_structure(dob,type)
+                    dob.obj=x.heading_body0
+                  elsif dob.ln==1
                     type="heading_section_#{dob.ln.to_s}"
                     xml_markup(dob)
                     xml_structure(dob,type)
