@@ -8,7 +8,8 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008, 2009, 2010, 2011, 2012, 2013 Ralph Amissah, All Rights Reserved.
+   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
+   All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -297,30 +298,34 @@ WOK
       %{<p class="norm">#{@p_num.name}#{@headname}#{@dob.obj} </p>} +
       %{<p class="paranum"><font size="1" color="#777777">&nbsp;&nbsp;#{@dob.ocn}</font></p>\n}
     end
-    def heading_body1
+    def heading_body0
       %{<h1 class="norm">#{@p_num.name}#{@headname}#{@dob.obj}</h1>} +
       %{<p class="paranum"><font size="1" color="#777777">&nbsp;&nbsp;#{@dob.ocn}</font></p>\n}
     end
-    def heading_body2
+    def heading_body1
       %{<h2 class="norm">#{@p_num.name}#{@headname}#{@dob.obj}</h2>} +
       %{<p class="paranum"><font size="1" color="#777777">&nbsp;&nbsp;#{@dob.ocn}</font></p>\n}
     end
-    def heading_body3
+    def heading_body2
       %{<h3 class="norm">#{@p_num.name}#{@headname}#{@dob.obj}</h3>} +
       %{<p class="paranum"><font size="1" color="#777777">&nbsp;&nbsp;#{@dob.ocn}</font></p>\n}
     end
-    def heading_body4
+    def heading_body3
       %{<h4 class="norm">#{@p_num.name}#{@headname}#{@dob.obj}</h4>} +
       %{<p class="paranum"><font size="1" color="#777777">&nbsp;&nbsp;#{@dob.ocn}</font></p>\n}
     end
-    def heading_body5
+    def heading_body4
       %{<h5 class="norm">#{@p_num.name}#{@headname}#{@dob.obj}</h5>} +
       %{<p class="paranum"><font size="1" color="#777777">&nbsp;&nbsp;#{@dob.ocn}</font></p>\n}
     end
-    def heading_body6
+    def heading_body5
       %{<h6 class="norm">#{@p_num.name}#{@headname}#{@dob.obj}</h6>} +
       %{<p class="paranum"><font size="1" color="#777777">&nbsp;&nbsp;#{@dob.ocn}</font></p>\n}
     end
+    def heading_body6
+      %{<h7 class="norm">#{@p_num.name}#{@headname}#{@dob.obj}</h7>} +
+      %{<p class="paranum"><font size="1" color="#777777">&nbsp;&nbsp;#{@dob.ocn}</font></p>\n}
+    end
   end
   class ParagraphNumber
     def initialize(md,ocn)
@@ -1089,6 +1094,9 @@ WOK
     def heading_body
       heading_normal('p','norm')
     end
+    def heading_body0
+      heading_normal('h1','norm')
+    end
     def heading_body1
       heading_normal('h1','norm')
     end
